@@ -25,7 +25,6 @@ import static org.apache.gravitino.Configs.ENTITY_RELATIONAL_JDBC_BACKEND_PATH;
 import static org.apache.gravitino.Configs.ENTITY_RELATIONAL_JDBC_BACKEND_URL;
 import static org.apache.gravitino.Configs.ENTITY_RELATIONAL_JDBC_BACKEND_USER;
 import static org.apache.gravitino.Configs.ENTITY_RELATIONAL_STORE;
-import static org.apache.gravitino.Configs.ENTITY_SERDE;
 import static org.apache.gravitino.Configs.ENTITY_STORE;
 import static org.apache.gravitino.Configs.RELATIONAL_ENTITY_STORE;
 import static org.apache.gravitino.Configs.STORE_DELETE_AFTER_TIME;
@@ -131,6 +130,11 @@ public class TestHadoopCatalogOperations {
         public PropertiesMetadata topicPropertiesMetadata() throws UnsupportedOperationException {
           throw new UnsupportedOperationException("Does not support topic properties");
         }
+
+        @Override
+        public PropertiesMetadata modelPropertiesMetadata() throws UnsupportedOperationException {
+          throw new UnsupportedOperationException("Does not support model properties");
+        }
       };
 
   private static EntityStore store;
@@ -184,7 +188,6 @@ public class TestHadoopCatalogOperations {
     when(config.get(VERSION_RETENTION_COUNT)).thenReturn(1L);
     when(config.get(STORE_TRANSACTION_MAX_SKEW_TIME)).thenReturn(1000L);
     when(config.get(STORE_DELETE_AFTER_TIME)).thenReturn(20 * 60 * 1000L);
-    when(config.get(ENTITY_SERDE)).thenReturn("proto");
 
     store = EntityStoreFactory.createEntityStore(config);
     store.initialize(config);
@@ -443,23 +446,39 @@ public class TestHadoopCatalogOperations {
       Assertions.assertFalse(fs.exists(schemaPath));
 
       // Test drop non-empty schema with cascade = false
-      Path subPath = new Path(schemaPath, "test1");
-      fs.mkdirs(subPath);
-      Assertions.assertTrue(fs.exists(subPath));
+      createSchema(name, comment, catalogPath, null);
+      Fileset fs1 = createFileset("fs1", name, "comment", Fileset.Type.MANAGED, catalogPath, null);
+      Path fs1Path = new Path(fs1.storageLocation());
 
       Throwable exception1 =
           Assertions.assertThrows(NonEmptySchemaException.class, () -> ops.dropSchema(id, false));
-      Assertions.assertEquals(
-          "Schema m1.c1.schema20 with location " + schemaPath + " is not empty",
-          exception1.getMessage());
+      Assertions.assertEquals("Schema m1.c1.schema20 is not empty", exception1.getMessage());
 
       // Test drop non-empty schema with cascade = true
       ops.dropSchema(id, true);
       Assertions.assertFalse(fs.exists(schemaPath));
+      Assertions.assertFalse(fs.exists(fs1Path));
 
-      // Test drop empty schema
-      Assertions.assertFalse(ops.dropSchema(id, true), "schema should be non-existent");
-      Assertions.assertFalse(ops.dropSchema(id, false), "schema should be non-existent");
+      // Test drop both managed and external filesets
+      createSchema(name, comment, catalogPath, null);
+      Fileset fs2 = createFileset("fs2", name, "comment", Fileset.Type.MANAGED, catalogPath, null);
+      Path fs2Path = new Path(fs2.storageLocation());
+
+      Path fs3Path = new Path(schemaPath, "fs3");
+      createFileset("fs3", name, "comment", Fileset.Type.EXTERNAL, catalogPath, fs3Path.toString());
+
+      ops.dropSchema(id, true);
+      Assertions.assertTrue(fs.exists(schemaPath));
+      Assertions.assertFalse(fs.exists(fs2Path));
+      // The path of external fileset should not be deleted
+      Assertions.assertTrue(fs.exists(fs3Path));
+
+      // Test drop schema with different storage location
+      createSchema(name, comment, catalogPath, null);
+      Path fs4Path = new Path(TEST_ROOT_PATH + "/fs4");
+      createFileset("fs4", name, "comment", Fileset.Type.MANAGED, catalogPath, fs4Path.toString());
+      ops.dropSchema(id, true);
+      Assertions.assertFalse(fs.exists(fs4Path));
     }
   }
 
@@ -720,6 +739,11 @@ public class TestHadoopCatalogOperations {
           public PropertiesMetadata topicPropertiesMetadata() throws UnsupportedOperationException {
             return null;
           }
+
+          @Override
+          public PropertiesMetadata modelPropertiesMetadata() throws UnsupportedOperationException {
+            return null;
+          }
         };
 
     try {
