@@ -24,4 +24,4 @@ def encode_string(to_encode: str):
     if to_encode is None:
         raise IllegalArgumentException("Invalid string to encode: None")
 
-    return urllib.parse.quote(to_encode)
+    return urllib.parse.quote(to_encode, encoding="utf-8")
