@@ -1,21 +1,19 @@
-"""
-Licensed to the Apache Software Foundation (ASF) under one
-or more contributor license agreements.  See the NOTICE file
-distributed with this work for additional information
-regarding copyright ownership.  The ASF licenses this file
-to you under the Apache License, Version 2.0 (the
-"License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
-
-  http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing,
-software distributed under the License is distributed on an
-"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-KIND, either express or implied.  See the License for the
-specific language governing permissions and limitations
-under the License.
-"""
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 # pylint: disable=protected-access
 
@@ -46,7 +44,7 @@ from gravitino import (
 from gravitino.auth.auth_constants import AuthConstants
 from gravitino.exceptions.base import GravitinoRuntimeException
 from tests.integration.integration_test_env import IntegrationTestEnv
-from tests.integration.hdfs_container import HDFSContainer
+from tests.integration.containers.hdfs_container import HDFSContainer
 from tests.integration.base_hadoop_env import BaseHadoopEnvironment
 
 logger = logging.getLogger(__name__)
@@ -91,9 +89,13 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         uri="http://localhost:8090"
     )
     gravitino_client: GravitinoClient = None
+    options = {}
 
     @classmethod
     def setUpClass(cls):
+
+        cls._get_gravitino_home()
+
         cls.hdfs_container = HDFSContainer()
         hdfs_container_ip = cls.hdfs_container.get_ip()
         # init hadoop env
@@ -101,8 +103,11 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         cls.config = {
             "gravitino.bypass.fs.defaultFS": f"hdfs://{hdfs_container_ip}:9000"
         }
+
+        cls.hadoop_conf_path = f"{cls.gravitino_home}/catalogs/hadoop/conf/hadoop.conf"
+
         # append the hadoop conf to server
-        cls._append_catalog_hadoop_conf(cls.config)
+        cls._append_conf(cls.config, cls.hadoop_conf_path)
         # restart the server
         cls.restart_server()
         # create entity
@@ -113,14 +118,15 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         try:
             cls._clean_test_data()
             # reset server conf
-            cls._reset_catalog_hadoop_conf(cls.config)
+            cls._reset_conf(cls.config, cls.hadoop_conf_path)
             # restart server
             cls.restart_server()
             # clear hadoop env
             BaseHadoopEnvironment.clear_hadoop_env()
         finally:
             # close hdfs container
-            cls.hdfs_container.close()
+            if cls.hdfs_container is not None:
+                cls.hdfs_container.close()
 
     @classmethod
     def _init_test_entities(cls):
@@ -155,21 +161,26 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
             properties=cls.fileset_properties,
         )
         arrow_hadoop_fs = HadoopFileSystem(host=cls.hdfs_container.get_ip(), port=9000)
-        cls.hdfs = ArrowFSWrapper(arrow_hadoop_fs)
+        cls.fs = ArrowFSWrapper(arrow_hadoop_fs)
         cls.conf: Dict = {"fs.defaultFS": f"hdfs://{cls.hdfs_container.get_ip()}:9000/"}
 
     @classmethod
     def _clean_test_data(cls):
+        cls.gravitino_client = GravitinoClient(
+            uri="http://localhost:8090", metalake_name=cls.metalake_name
+        )
+        catalog = cls.gravitino_client.load_catalog(name=cls.catalog_name)
+
         try:
-            cls.gravitino_client = GravitinoClient(
-                uri="http://localhost:8090", metalake_name=cls.metalake_name
-            )
-            catalog = cls.gravitino_client.load_catalog(name=cls.catalog_name)
             logger.info(
                 "Drop fileset %s[%s]",
                 cls.fileset_ident,
                 catalog.as_fileset_catalog().drop_fileset(ident=cls.fileset_ident),
             )
+        except GravitinoRuntimeException:
+            logger.warning("Failed to drop fileset %s", cls.fileset_ident)
+
+        try:
             logger.info(
                 "Drop schema %s[%s]",
                 cls.schema_ident,
@@ -177,18 +188,26 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
                     schema_name=cls.schema_name, cascade=True
                 ),
             )
+        except GravitinoRuntimeException:
+            logger.warning("Failed to drop schema %s", cls.schema_name)
+
+        try:
             logger.info(
                 "Drop catalog %s[%s]",
                 cls.catalog_name,
-                cls.gravitino_client.drop_catalog(name=cls.catalog_name),
+                cls.gravitino_client.drop_catalog(name=cls.catalog_name, force=True),
             )
+        except GravitinoRuntimeException:
+            logger.warning("Failed to drop catalog %s", cls.catalog_name)
+
+        try:
             logger.info(
                 "Drop metalake %s[%s]",
                 cls.metalake_name,
                 cls.gravitino_admin_client.drop_metalake(cls.metalake_name),
             )
-        except Exception as e:
-            logger.error("Clean test data failed: %s", e)
+        except GravitinoRuntimeException:
+            logger.warning("Failed to drop metalake %s", cls.metalake_name)
 
     def test_simple_auth(self):
         options = {"auth_type": "simple"}
@@ -217,15 +236,16 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(ls_actual_dir)
-        self.assertTrue(self.hdfs.exists(ls_actual_dir))
+
+        self.check_mkdir(ls_dir, ls_actual_dir, fs)
 
         ls_file = self.fileset_gvfs_location + "/test_ls/test.file"
         ls_actual_file = self.fileset_storage_location + "/test_ls/test.file"
-        self.hdfs.touch(ls_actual_file)
-        self.assertTrue(self.hdfs.exists(ls_actual_file))
+        self.fs.touch(ls_actual_file)
+        self.assertTrue(self.fs.exists(ls_actual_file))
 
         # test detail = false
         file_list_without_detail = fs.ls(ls_dir, detail=False)
@@ -243,15 +263,16 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(info_actual_dir)
-        self.assertTrue(self.hdfs.exists(info_actual_dir))
+
+        self.check_mkdir(info_dir, info_actual_dir, fs)
 
         info_file = self.fileset_gvfs_location + "/test_info/test.file"
         info_actual_file = self.fileset_storage_location + "/test_info/test.file"
-        self.hdfs.touch(info_actual_file)
-        self.assertTrue(self.hdfs.exists(info_actual_file))
+        self.fs.touch(info_actual_file)
+        self.assertTrue(self.fs.exists(info_actual_file))
 
         dir_info = fs.info(info_dir)
         self.assertEqual(dir_info["name"], info_dir[len("gvfs://") :])
@@ -265,16 +286,15 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(exist_actual_dir)
-        self.assertTrue(self.hdfs.exists(exist_actual_dir))
-        self.assertTrue(fs.exists(exist_dir))
+        self.check_mkdir(exist_dir, exist_actual_dir, fs)
 
         exist_file = self.fileset_gvfs_location + "/test_exist/test.file"
         exist_actual_file = self.fileset_storage_location + "/test_exist/test.file"
-        self.hdfs.touch(exist_actual_file)
-        self.assertTrue(self.hdfs.exists(exist_actual_file))
+        self.fs.touch(exist_actual_file)
+        self.assertTrue(self.fs.exists(exist_actual_file))
         self.assertTrue(fs.exists(exist_file))
 
     def test_cp_file(self):
@@ -283,19 +303,19 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(cp_file_actual_dir)
-        self.assertTrue(self.hdfs.exists(cp_file_actual_dir))
-        self.assertTrue(fs.exists(cp_file_dir))
+
+        self.check_mkdir(cp_file_dir, cp_file_actual_dir, fs)
 
         cp_file_file = self.fileset_gvfs_location + "/test_cp_file/test.file"
         cp_file_actual_file = self.fileset_storage_location + "/test_cp_file/test.file"
-        self.hdfs.touch(cp_file_actual_file)
-        self.assertTrue(self.hdfs.exists(cp_file_actual_file))
+        self.fs.touch(cp_file_actual_file)
+        self.assertTrue(self.fs.exists(cp_file_actual_file))
         self.assertTrue(fs.exists(cp_file_file))
 
-        with self.hdfs.open(cp_file_actual_file, "wb") as f:
+        with self.fs.open(cp_file_actual_file, "wb") as f:
             f.write(b"test_file_1")
 
         cp_file_new_file = self.fileset_gvfs_location + "/test_cp_file/test_cp.file"
@@ -305,7 +325,7 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs.cp_file(cp_file_file, cp_file_new_file)
         self.assertTrue(fs.exists(cp_file_new_file))
 
-        with self.hdfs.open(cp_file_new_actual_file, "rb") as f:
+        with self.fs.open(cp_file_new_actual_file, "rb") as f:
             result = f.read()
         self.assertEqual(b"test_file_1", result)
 
@@ -315,27 +335,26 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(mv_actual_dir)
-        self.assertTrue(self.hdfs.exists(mv_actual_dir))
-        self.assertTrue(fs.exists(mv_dir))
+        self.check_mkdir(mv_dir, mv_actual_dir, fs)
 
         mv_new_dir = self.fileset_gvfs_location + "/test_mv_new"
         mv_new_actual_dir = self.fileset_storage_location + "/test_mv_new"
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(mv_new_actual_dir)
-        self.assertTrue(self.hdfs.exists(mv_new_actual_dir))
-        self.assertTrue(fs.exists(mv_new_dir))
+
+        self.check_mkdir(mv_new_dir, mv_new_actual_dir, fs)
 
         mv_file = self.fileset_gvfs_location + "/test_mv/test.file"
         mv_actual_file = self.fileset_storage_location + "/test_mv/test.file"
-        self.hdfs.touch(mv_actual_file)
-        self.assertTrue(self.hdfs.exists(mv_actual_file))
+        self.fs.touch(mv_actual_file)
+        self.assertTrue(self.fs.exists(mv_actual_file))
         self.assertTrue(fs.exists(mv_file))
 
         mv_new_file = self.fileset_gvfs_location + "/test_mv_new/test_new.file"
@@ -345,7 +364,11 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
 
         fs.mv(mv_file, mv_new_file)
         self.assertTrue(fs.exists(mv_new_file))
-        self.assertTrue(self.hdfs.exists(mv_new_actual_file))
+        self.assertTrue(self.fs.exists(mv_new_actual_file))
+
+        # test rename without sub path, which should throw an exception
+        with self.assertRaises(GravitinoRuntimeException):
+            fs.mv(self.fileset_gvfs_location, self.fileset_gvfs_location + "/test_mv")
 
     def test_rm(self):
         rm_dir = self.fileset_gvfs_location + "/test_rm"
@@ -353,16 +376,15 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(rm_actual_dir)
-        self.assertTrue(self.hdfs.exists(rm_actual_dir))
-        self.assertTrue(fs.exists(rm_dir))
+        self.check_mkdir(rm_dir, rm_actual_dir, fs)
 
         rm_file = self.fileset_gvfs_location + "/test_rm/test.file"
         rm_actual_file = self.fileset_storage_location + "/test_rm/test.file"
-        self.hdfs.touch(rm_file)
-        self.assertTrue(self.hdfs.exists(rm_actual_file))
+        fs.touch(rm_file)
+        self.assertTrue(self.fs.exists(rm_actual_file))
         self.assertTrue(fs.exists(rm_file))
 
         # test delete file
@@ -372,8 +394,8 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         # test delete dir with recursive = false
         rm_new_file = self.fileset_gvfs_location + "/test_rm/test_new.file"
         rm_new_actual_file = self.fileset_storage_location + "/test_rm/test_new.file"
-        self.hdfs.touch(rm_new_actual_file)
-        self.assertTrue(self.hdfs.exists(rm_new_actual_file))
+        self.fs.touch(rm_new_actual_file)
+        self.assertTrue(self.fs.exists(rm_new_actual_file))
         self.assertTrue(fs.exists(rm_new_file))
         with self.assertRaises(ValueError):
             fs.rm(rm_dir, recursive=False)
@@ -388,16 +410,15 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(rm_file_actual_dir)
-        self.assertTrue(self.hdfs.exists(rm_file_actual_dir))
-        self.assertTrue(fs.exists(rm_file_dir))
+        self.check_mkdir(rm_file_dir, rm_file_actual_dir, fs)
 
         rm_file_file = self.fileset_gvfs_location + "/test_rm_file/test.file"
         rm_file_actual_file = self.fileset_storage_location + "/test_rm_file/test.file"
-        self.hdfs.touch(rm_file_actual_file)
-        self.assertTrue(self.hdfs.exists(rm_file_actual_file))
+        self.fs.touch(rm_file_actual_file)
+        self.assertTrue(self.fs.exists(rm_file_actual_file))
         self.assertTrue(fs.exists(rm_file_file))
 
         # test delete file
@@ -414,16 +435,15 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(rmdir_actual_dir)
-        self.assertTrue(self.hdfs.exists(rmdir_actual_dir))
-        self.assertTrue(fs.exists(rmdir_dir))
+        self.check_mkdir(rmdir_dir, rmdir_actual_dir, fs)
 
         rmdir_file = self.fileset_gvfs_location + "/test_rmdir/test.file"
         rmdir_actual_file = self.fileset_storage_location + "/test_rmdir/test.file"
-        self.hdfs.touch(rmdir_actual_file)
-        self.assertTrue(self.hdfs.exists(rmdir_actual_file))
+        self.fs.touch(rmdir_actual_file)
+        self.assertTrue(self.fs.exists(rmdir_actual_file))
         self.assertTrue(fs.exists(rmdir_file))
 
         # test delete file
@@ -440,16 +460,15 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(open_actual_dir)
-        self.assertTrue(self.hdfs.exists(open_actual_dir))
-        self.assertTrue(fs.exists(open_dir))
+        self.check_mkdir(open_dir, open_actual_dir, fs)
 
         open_file = self.fileset_gvfs_location + "/test_open/test.file"
         open_actual_file = self.fileset_storage_location + "/test_open/test.file"
-        self.hdfs.touch(open_actual_file)
-        self.assertTrue(self.hdfs.exists(open_actual_file))
+        self.fs.touch(open_actual_file)
+        self.assertTrue(self.fs.exists(open_actual_file))
         self.assertTrue(fs.exists(open_file))
 
         # test open and write file
@@ -467,11 +486,10 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        fs.mkdir(mkdir_dir)
-        self.assertTrue(fs.exists(mkdir_dir))
-        self.assertTrue(self.hdfs.exists(mkdir_actual_dir))
+        self.check_mkdir(mkdir_dir, mkdir_actual_dir, fs)
 
         # test mkdir dir with create_parents = false
         parent_not_exist_virtual_path = mkdir_dir + "/not_exist/sub_dir"
@@ -493,11 +511,10 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        fs.makedirs(makedirs_dir)
-        self.assertTrue(fs.exists(makedirs_dir))
-        self.assertTrue(self.hdfs.exists(makedirs_actual_dir))
+        self.check_makedirs(makedirs_dir, makedirs_actual_dir, fs)
 
         # test mkdir dir not exist
         parent_not_exist_virtual_path = makedirs_dir + "/not_exist/sub_dir"
@@ -511,11 +528,11 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(created_actual_dir)
-        self.assertTrue(self.hdfs.exists(created_actual_dir))
-        self.assertTrue(fs.exists(created_dir))
+
+        self.check_mkdir(created_dir, created_actual_dir, fs)
 
         with self.assertRaises(GravitinoRuntimeException):
             fs.created(created_dir)
@@ -526,31 +543,41 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(modified_actual_dir)
-        self.assertTrue(self.hdfs.exists(modified_actual_dir))
-        self.assertTrue(fs.exists(modified_dir))
+
+        self.check_mkdir(modified_dir, modified_actual_dir, fs)
 
         # test mkdir dir which exists
         self.assertIsNotNone(fs.modified(modified_dir))
 
+    def check_mkdir(self, gvfs_dir, actual_dir, gvfs_instance):
+        self.fs.mkdir(actual_dir)
+        self.assertTrue(self.fs.exists(actual_dir))
+        self.assertTrue(gvfs_instance.exists(gvfs_dir))
+
+    def check_makedirs(self, gvfs_dir, actual_dir, gvfs_instance):
+        self.fs.makedirs(actual_dir)
+        self.assertTrue(self.fs.exists(actual_dir))
+        self.assertTrue(gvfs_instance.exists(gvfs_dir))
+
     def test_cat_file(self):
         cat_dir = self.fileset_gvfs_location + "/test_cat"
         cat_actual_dir = self.fileset_storage_location + "/test_cat"
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(cat_actual_dir)
-        self.assertTrue(self.hdfs.exists(cat_actual_dir))
-        self.assertTrue(fs.exists(cat_dir))
+
+        self.check_mkdir(cat_dir, cat_actual_dir, fs)
 
         cat_file = self.fileset_gvfs_location + "/test_cat/test.file"
         cat_actual_file = self.fileset_storage_location + "/test_cat/test.file"
-        self.hdfs.touch(cat_actual_file)
-        self.assertTrue(self.hdfs.exists(cat_actual_file))
+        self.fs.touch(cat_actual_file)
+        self.assertTrue(self.fs.exists(cat_actual_file))
         self.assertTrue(fs.exists(cat_file))
 
         # test open and write file
@@ -568,16 +595,16 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(get_actual_dir)
-        self.assertTrue(self.hdfs.exists(get_actual_dir))
-        self.assertTrue(fs.exists(get_dir))
+
+        self.check_mkdir(get_dir, get_actual_dir, fs)
 
         get_file = self.fileset_gvfs_location + "/test_get/test.file"
         get_actual_file = self.fileset_storage_location + "/test_get/test.file"
-        self.hdfs.touch(get_actual_file)
-        self.assertTrue(self.hdfs.exists(get_actual_file))
+        self.fs.touch(get_actual_file)
+        self.assertTrue(self.fs.exists(get_actual_file))
         self.assertTrue(fs.exists(get_file))
 
         # test open and write file
@@ -607,11 +634,11 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(pands_actual_dir)
-        self.assertTrue(self.hdfs.exists(pands_actual_dir))
-        self.assertTrue(fs.exists(pands_dir))
+
+        self.check_mkdir(pands_dir, pands_actual_dir, fs)
 
         data = pandas.DataFrame({"Name": ["A", "B", "C", "D"], "ID": [20, 21, 19, 18]})
         # to parquet
@@ -621,7 +648,7 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         )
         data.to_parquet(parquet_file, filesystem=fs)
         self.assertTrue(fs.exists(parquet_file))
-        self.assertTrue(self.hdfs.exists(parquet_actual_file))
+        self.assertTrue(self.fs.exists(parquet_actual_file))
 
         # read parquet
         ds1 = pandas.read_parquet(path=parquet_file, filesystem=fs)
@@ -629,6 +656,7 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         storage_options = {
             "server_uri": "http://localhost:8090",
             "metalake_name": self.metalake_name,
+            "options": self.options,
         }
         # to csv
         csv_file = self.fileset_gvfs_location + "/test_pandas/test.csv"
@@ -639,7 +667,7 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
             storage_options=storage_options,
         )
         self.assertTrue(fs.exists(csv_file))
-        self.assertTrue(self.hdfs.exists(csv_actual_file))
+        self.assertTrue(self.fs.exists(csv_actual_file))
 
         # read csv
         ds2 = pandas.read_csv(csv_file, storage_options=storage_options)
@@ -651,11 +679,11 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(pyarrow_actual_dir)
-        self.assertTrue(self.hdfs.exists(pyarrow_actual_dir))
-        self.assertTrue(fs.exists(pyarrow_dir))
+
+        self.check_mkdir(pyarrow_dir, pyarrow_actual_dir, fs)
 
         data = pandas.DataFrame({"Name": ["A", "B", "C", "D"], "ID": [20, 21, 19, 18]})
         # to parquet
@@ -680,16 +708,17 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
         fs = gvfs.GravitinoVirtualFileSystem(
             server_uri="http://localhost:8090",
             metalake_name=self.metalake_name,
+            options=self.options,
             **self.conf,
         )
-        self.hdfs.mkdir(llama_actual_dir)
-        self.assertTrue(self.hdfs.exists(llama_actual_dir))
-        self.assertTrue(fs.exists(llama_dir))
+        self.check_mkdir(llama_dir, llama_actual_dir, fs)
+
         data = pandas.DataFrame({"Name": ["A", "B", "C", "D"], "ID": [20, 21, 19, 18]})
 
         storage_options = {
             "server_uri": "http://localhost:8090",
             "metalake_name": self.metalake_name,
+            "options": self.options,
         }
         csv_file = llama_dir + "/test.csv"
         # to csv
