@@ -19,7 +19,8 @@ import json
 from unittest.mock import patch
 
 from gravitino import GravitinoMetalake, Catalog, Fileset
-from gravitino.catalog.fileset_catalog import FilesetCatalog
+from gravitino.client.fileset_catalog import FilesetCatalog
+from gravitino.client.generic_model_catalog import GenericModelCatalog
 from gravitino.dto.fileset_dto import FilesetDTO
 from gravitino.dto.audit_dto import AuditDTO
 from gravitino.dto.metalake_dto import MetalakeDTO
@@ -43,7 +44,7 @@ def mock_load_metalake():
     return GravitinoMetalake(metalake_dto)
 
 
-def mock_load_fileset_catalog():
+def mock_load_catalog(name: str):
     audit_dto = AuditDTO(
         _creator="test",
         _create_time="2022-01-01T00:00:00Z",
@@ -53,16 +54,32 @@ def mock_load_fileset_catalog():
 
     namespace = Namespace.of("metalake_demo")
 
-    catalog = FilesetCatalog(
-        namespace=namespace,
-        name="fileset_catalog",
-        catalog_type=Catalog.Type.FILESET,
-        provider="hadoop",
-        comment="this is test",
-        properties={"k": "v"},
-        audit=audit_dto,
-        rest_client=HTTPClient("http://localhost:9090", is_debug=True),
-    )
+    catalog = None
+    if name == "fileset_catalog":
+        catalog = FilesetCatalog(
+            namespace=namespace,
+            name=name,
+            catalog_type=Catalog.Type.FILESET,
+            provider="hadoop",
+            comment="this is test",
+            properties={"k": "v"},
+            audit=audit_dto,
+            rest_client=HTTPClient("http://localhost:9090", is_debug=True),
+        )
+    elif name == "model_catalog":
+        catalog = GenericModelCatalog(
+            namespace=namespace,
+            name=name,
+            catalog_type=Catalog.Type.MODEL,
+            provider="hadoop",
+            comment="this is test",
+            properties={"k": "v"},
+            audit=audit_dto,
+            rest_client=HTTPClient("http://localhost:9090", is_debug=True),
+        )
+    else:
+        raise ValueError(f"Unknown catalog name: {name}")
+
     return catalog
 
 
@@ -91,7 +108,11 @@ def mock_data(cls):
     )
     @patch(
         "gravitino.client.gravitino_metalake.GravitinoMetalake.load_catalog",
-        return_value=mock_load_fileset_catalog(),
+        side_effect=mock_load_catalog,
+    )
+    @patch(
+        "gravitino.client.fileset_catalog.FilesetCatalog.load_fileset",
+        return_value=mock_load_fileset("fileset", ""),
     )
     @patch(
         "gravitino.client.gravitino_client_base.GravitinoClientBase.check_version",
