@@ -49,6 +49,7 @@ from tests.unittests.auth.mock_base import (
 )
 
 
+# pylint: disable=C0302
 def generate_unique_random_string(length):
     characters = string.ascii_letters + string.digits
     random_string = "".join(random.sample(characters, length))
@@ -77,7 +78,7 @@ class TestLocalFilesystem(unittest.TestCase):
         fileset_virtual_location = "fileset/fileset_catalog/tmp/test_cache"
         actual_path = fileset_storage_location
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             local_fs = LocalFileSystem()
@@ -139,7 +140,7 @@ class TestLocalFilesystem(unittest.TestCase):
             fileset_virtual_location = "fileset/fileset_catalog/tmp/test_oauth2_auth"
             actual_path = fileset_storage_location
             with patch(
-                "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+                "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
                 return_value=actual_path,
             ):
                 local_fs = LocalFileSystem()
@@ -190,7 +191,7 @@ class TestLocalFilesystem(unittest.TestCase):
         fileset_virtual_location = "fileset/fileset_catalog/tmp/test_ls"
         actual_path = fileset_storage_location
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             local_fs = LocalFileSystem()
@@ -252,7 +253,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -260,7 +261,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/test_1"
         actual_path = fileset_storage_location + "/test_1"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             dir_info = fs.info(dir_virtual_path)
@@ -269,7 +270,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             file_info = fs.info(file_virtual_path)
@@ -294,7 +295,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -302,7 +303,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/test_1"
         actual_path = fileset_storage_location + "/test_1"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -310,7 +311,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -334,7 +335,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -343,7 +344,7 @@ class TestLocalFilesystem(unittest.TestCase):
         src_actual_path = fileset_storage_location + "/test_file_1.par"
         dst_actual_path = fileset_storage_location + "/test_cp_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[
                 src_actual_path,
                 src_actual_path,
@@ -386,7 +387,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -394,7 +395,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         src_actual_path = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=src_actual_path,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -402,7 +403,7 @@ class TestLocalFilesystem(unittest.TestCase):
         mv_file_virtual_path = fileset_virtual_location + "/test_cp_file_1.par"
         dst_actual_path = fileset_storage_location + "/test_cp_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[src_actual_path, dst_actual_path, dst_actual_path],
         ):
             fs.mv(file_virtual_path, mv_file_virtual_path)
@@ -413,7 +414,7 @@ class TestLocalFilesystem(unittest.TestCase):
         )
         dst_actual_path1 = fileset_storage_location + "/another_dir/test_file_2.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[dst_actual_path, dst_actual_path1, dst_actual_path1],
         ):
             fs.mv(mv_file_virtual_path, mv_another_dir_virtual_path)
@@ -423,7 +424,7 @@ class TestLocalFilesystem(unittest.TestCase):
         not_exist_dst_dir_path = fileset_virtual_location + "/not_exist/test_file_2.par"
         dst_actual_path2 = fileset_storage_location + "/not_exist/test_file_2.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[dst_actual_path1, dst_actual_path2],
         ):
             with self.assertRaises(FileNotFoundError):
@@ -456,7 +457,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -465,7 +466,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path1 = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -476,7 +477,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path2 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -508,7 +509,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -517,7 +518,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path1 = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -528,7 +529,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path2 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -555,7 +556,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -564,7 +565,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path1 = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -575,7 +576,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path2 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -602,7 +603,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -611,7 +612,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path1 = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -627,7 +628,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path2 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -650,7 +651,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -665,7 +666,7 @@ class TestLocalFilesystem(unittest.TestCase):
         parent_not_exist_virtual_path = fileset_virtual_location + "/not_exist/sub_dir"
         actual_path1 = fileset_storage_location + "/not_exist/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertFalse(fs.exists(parent_not_exist_virtual_path))
@@ -676,7 +677,7 @@ class TestLocalFilesystem(unittest.TestCase):
         parent_not_exist_virtual_path2 = fileset_virtual_location + "/not_exist/sub_dir"
         actual_path2 = fileset_storage_location + "/not_exist/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             self.assertFalse(fs.exists(parent_not_exist_virtual_path2))
@@ -699,7 +700,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -714,7 +715,7 @@ class TestLocalFilesystem(unittest.TestCase):
         parent_not_exist_virtual_path = fileset_virtual_location + "/not_exist/sub_dir"
         actual_path1 = fileset_storage_location + "/not_exist/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertFalse(fs.exists(parent_not_exist_virtual_path))
@@ -737,7 +738,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -746,7 +747,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path1 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -768,7 +769,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -777,7 +778,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path1 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -803,7 +804,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -812,7 +813,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path1 = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -828,7 +829,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path2 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
@@ -855,7 +856,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -864,7 +865,7 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path1 = fileset_storage_location + "/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             self.assertTrue(fs.exists(file_virtual_path))
@@ -883,7 +884,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/sub_dir"
         actual_path2 = fileset_storage_location + "/sub_dir"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             local_path = self._fileset_dir + "/local_dir"
@@ -1076,7 +1077,7 @@ class TestLocalFilesystem(unittest.TestCase):
         )
         actual_path = fileset_storage_location + "/test.parquet"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             # to parquet
@@ -1097,7 +1098,7 @@ class TestLocalFilesystem(unittest.TestCase):
         actual_path2 = fileset_storage_location + "/test.csv"
 
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[actual_path1, actual_path2, actual_path2],
         ):
             # to csv
@@ -1127,7 +1128,7 @@ class TestLocalFilesystem(unittest.TestCase):
         )
         actual_path = fileset_storage_location + "/test.parquet"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             # to parquet
@@ -1172,7 +1173,7 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -1180,7 +1181,7 @@ class TestLocalFilesystem(unittest.TestCase):
         dir_virtual_path = fileset_virtual_location + "/test_1"
         actual_path1 = fileset_storage_location + "test_1"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path1,
         ):
             dir_info = fs.info(dir_virtual_path)
@@ -1189,14 +1190,14 @@ class TestLocalFilesystem(unittest.TestCase):
         file_virtual_path = fileset_virtual_location + "/test_1/test_file_1.par"
         actual_path2 = fileset_storage_location + "test_1/test_file_1.par"
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path2,
         ):
             file_info = fs.info(file_virtual_path)
             self.assertEqual(file_info["name"], file_virtual_path)
 
         with patch(
-            "gravitino.catalog.fileset_catalog.FilesetCatalog.get_file_location",
+            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             return_value=actual_path,
         ):
             file_status = fs.ls(fileset_virtual_location, detail=True)
