@@ -18,8 +18,6 @@
  */
 package org.apache.gravitino.filesystem.hadoop;
 
-import org.apache.gravitino.catalog.hadoop.fs.FileSystemProvider;
-
 /** Configuration class for Gravitino Virtual File System. */
 public class GravitinoVirtualFileSystemConfiguration {
 
@@ -44,13 +42,6 @@ public class GravitinoVirtualFileSystemConfiguration {
   /** The configuration key for the Gravitino client auth type. */
   public static final String FS_GRAVITINO_CLIENT_AUTH_TYPE_KEY = "fs.gravitino.client.authType";
 
-  /**
-   * File system provider names configuration key. The value is a comma separated list of file
-   * system provider name which is defined in the service loader. Users can custom their own file
-   * system by implementing the {@link FileSystemProvider} interface.
-   */
-  public static final String FS_FILESYSTEM_PROVIDERS = "fs.gvfs.filesystem.providers";
-
   /** The authentication type for simple authentication. */
   public static final String SIMPLE_AUTH_TYPE = "simple";
   /** The authentication type for oauth2 authentication. */
