@@ -29,6 +29,7 @@ import java.util.Set;
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;
 import java.util.stream.Collectors;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.gravitino.Catalog;
 import org.apache.gravitino.Entity;
 import org.apache.gravitino.GravitinoEnv;
@@ -416,7 +417,7 @@ public class AuthorizationUtils {
       if (defaultSchemaLocation != null && !defaultSchemaLocation.isEmpty()) {
         return defaultSchemaLocation;
       } else {
-        LOG.warn("Schema %s location is not found", defaultSchemaIdent);
+        LOG.warn("Schema {} location is not found", defaultSchemaIdent);
       }
     }
 
@@ -476,10 +477,10 @@ public class AuthorizationUtils {
               Schema schema = GravitinoEnv.getInstance().schemaDispatcher().loadSchema(ident);
               if (schema.properties().containsKey(HiveConstants.LOCATION)) {
                 String schemaLocation = schema.properties().get(HiveConstants.LOCATION);
-                if (schemaLocation != null && schemaLocation.isEmpty()) {
+                if (StringUtils.isNotBlank(schemaLocation)) {
                   locations.add(schemaLocation);
                 } else {
-                  LOG.warn("Schema %s location is not found", ident);
+                  LOG.warn("Schema {} location is not found", ident);
                 }
               }
             }
@@ -497,10 +498,10 @@ public class AuthorizationUtils {
               Table table = GravitinoEnv.getInstance().tableDispatcher().loadTable(ident);
               if (table.properties().containsKey(HiveConstants.LOCATION)) {
                 String tableLocation = table.properties().get(HiveConstants.LOCATION);
-                if (tableLocation != null && tableLocation.isEmpty()) {
+                if (StringUtils.isNotBlank(tableLocation)) {
                   locations.add(tableLocation);
                 } else {
-                  LOG.warn("Table %s location is not found", ident);
+                  LOG.warn("Table {} location is not found", ident);
                 }
               }
             }
@@ -521,7 +522,7 @@ public class AuthorizationUtils {
               "Failed to get location paths for metadata object %s type %s", ident, type);
       }
     } catch (Exception e) {
-      LOG.warn("Failed to get location paths for metadata object %s type %s", ident, type, e);
+      LOG.warn("Failed to get location paths for metadata object {} type {}", ident, type, e);
     }
 
     return locations;
