@@ -195,7 +195,7 @@ public class TopicOperationDispatcher extends OperationDispatcher implements Top
             getStringIdFromProperties(alteredTopic.properties()).id());
 
     return EntityCombinedTopic.of(alteredTopic, updatedTopicEntity)
-        .withHiddenPropertiesSet(
+        .withHiddenProperties(
             getHiddenPropertyNames(
                 catalogIdent,
                 HasPropertyMetadata::topicPropertiesMetadata,
@@ -303,7 +303,7 @@ public class TopicOperationDispatcher extends OperationDispatcher implements Top
     StringIdentifier stringId = getStringIdFromProperties(topic.properties());
     if (stringId == null) {
       return EntityCombinedTopic.of(topic)
-          .withHiddenPropertiesSet(
+          .withHiddenProperties(
               getHiddenPropertyNames(
                   catalogIdent, HasPropertyMetadata::topicPropertiesMetadata, topic.properties()))
           .withImported(isEntityExist(ident, TOPIC));
@@ -317,7 +317,7 @@ public class TopicOperationDispatcher extends OperationDispatcher implements Top
             getStringIdFromProperties(topic.properties()).id());
 
     return EntityCombinedTopic.of(topic, topicEntity)
-        .withHiddenPropertiesSet(
+        .withHiddenProperties(
             getHiddenPropertyNames(
                 catalogIdent, HasPropertyMetadata::topicPropertiesMetadata, topic.properties()))
         .withImported(topicEntity != null);
@@ -368,13 +368,13 @@ public class TopicOperationDispatcher extends OperationDispatcher implements Top
     } catch (Exception e) {
       LOG.error(OperationDispatcher.FormattedErrorMessages.STORE_OP_FAILURE, "put", ident, e);
       return EntityCombinedTopic.of(topic)
-          .withHiddenPropertiesSet(
+          .withHiddenProperties(
               getHiddenPropertyNames(
                   catalogIdent, HasPropertyMetadata::topicPropertiesMetadata, topic.properties()));
     }
 
     return EntityCombinedTopic.of(topic, topicEntity)
-        .withHiddenPropertiesSet(
+        .withHiddenProperties(
             getHiddenPropertyNames(
                 catalogIdent, HasPropertyMetadata::topicPropertiesMetadata, topic.properties()));
   }
