@@ -19,24 +19,19 @@
 package org.apache.gravitino.connector;
 
 import com.google.common.base.Preconditions;
-import com.google.common.collect.Iterables;
 import com.google.common.collect.Maps;
-import com.google.common.collect.Streams;
 import java.io.Closeable;
 import java.io.IOException;
-import java.util.List;
 import java.util.Map;
 import java.util.Optional;
-import java.util.ServiceLoader;
-import java.util.stream.Collectors;
 import org.apache.gravitino.Audit;
 import org.apache.gravitino.Catalog;
 import org.apache.gravitino.CatalogProvider;
 import org.apache.gravitino.annotation.Evolving;
 import org.apache.gravitino.connector.authorization.AuthorizationPlugin;
-import org.apache.gravitino.connector.authorization.AuthorizationProvider;
 import org.apache.gravitino.connector.authorization.BaseAuthorization;
 import org.apache.gravitino.connector.capability.Capability;
+import org.apache.gravitino.credential.CatalogCredentialManager;
 import org.apache.gravitino.meta.CatalogEntity;
 import org.apache.gravitino.utils.IsolatedClassLoader;
 import org.slf4j.Logger;
@@ -57,6 +52,7 @@ import org.slf4j.LoggerFactory;
 @Evolving
 public abstract class BaseCatalog<T extends BaseCatalog>
     implements Catalog, CatalogProvider, HasPropertyMetadata, Closeable {
+
   private static final Logger LOG = LoggerFactory.getLogger(BaseCatalog.class);
 
   // This variable is used as a key in properties of catalogs to inject custom operation to
@@ -66,7 +62,7 @@ public abstract class BaseCatalog<T extends BaseCatalog>
   public static final String CATALOG_OPERATION_IMPL = "ops-impl";
 
   // Underlying access control system plugin for this catalog.
-  private volatile BaseAuthorization<?> authorization;
+  private volatile AuthorizationPlugin authorizationPlugin;
 
   private CatalogEntity entity;
 
@@ -78,6 +74,8 @@ public abstract class BaseCatalog<T extends BaseCatalog>
 
   private volatile Map<String, String> properties;
 
+  private volatile CatalogCredentialManager catalogCredentialManager;
+
   private static String ENTITY_IS_NOT_SET = "entity is not set";
 
   // Any Gravitino configuration that starts with this prefix will be trim and passed to the
@@ -151,6 +149,12 @@ public abstract class BaseCatalog<T extends BaseCatalog>
         "The catalog does not support topic properties metadata");
   }
 
+  @Override
+  public PropertiesMetadata modelPropertiesMetadata() throws UnsupportedOperationException {
+    throw new UnsupportedOperationException(
+        "The catalog does not support model properties metadata");
+  }
+
   /**
    * Retrieves the CatalogOperations instance associated with this catalog. Lazily initializes the
    * instance if not already created.
@@ -181,54 +185,44 @@ public abstract class BaseCatalog<T extends BaseCatalog>
   }
 
   public AuthorizationPlugin getAuthorizationPlugin() {
-    if (authorization == null) {
-      return null;
+    if (authorizationPlugin == null) {
+      synchronized (this) {
+        if (authorizationPlugin == null) {
+          return null;
+        }
+      }
     }
-    return authorization.plugin(provider(), this.conf);
+    return authorizationPlugin;
   }
 
   public void initAuthorizationPluginInstance(IsolatedClassLoader classLoader) {
-    if (authorization != null) {
-      return;
-    }
+    if (authorizationPlugin == null) {
+      synchronized (this) {
+        if (authorizationPlugin == null) {
+          String authorizationProvider =
+              (String) catalogPropertiesMetadata().getOrDefault(conf, AUTHORIZATION_PROVIDER);
+          if (authorizationProvider == null) {
+            LOG.info("Authorization provider is not set!");
+            return;
+          }
+          try {
+            BaseAuthorization<?> authorization =
+                BaseAuthorization.createAuthorization(classLoader, authorizationProvider);
 
-    String authorizationProvider =
-        (String) catalogPropertiesMetadata().getOrDefault(conf, AUTHORIZATION_PROVIDER);
-    if (authorizationProvider == null) {
-      LOG.info("Authorization provider is not set!");
-      return;
-    }
+            // Load the authorization plugin with the class loader of the catalog.
+            // Because the JDBC authorization plugin may load JDBC driver using the class loader.
+            authorizationPlugin =
+                classLoader.withClassLoader(
+                    cl ->
+                        authorization.newPlugin(
+                            entity.namespace().level(0), provider(), this.conf));
 
-    try {
-      authorization =
-          classLoader.withClassLoader(
-              cl -> {
-                try {
-                  ServiceLoader<AuthorizationProvider> loader =
-                      ServiceLoader.load(AuthorizationProvider.class, cl);
-
-                  List<Class<? extends AuthorizationProvider>> providers =
-                      Streams.stream(loader.iterator())
-                          .filter(p -> p.shortName().equalsIgnoreCase(authorizationProvider))
-                          .map(AuthorizationProvider::getClass)
-                          .collect(Collectors.toList());
-                  if (providers.isEmpty()) {
-                    throw new IllegalArgumentException(
-                        "No authorization provider found for: " + authorizationProvider);
-                  } else if (providers.size() > 1) {
-                    throw new IllegalArgumentException(
-                        "Multiple authorization providers found for: " + authorizationProvider);
-                  }
-                  return (BaseAuthorization<?>)
-                      Iterables.getOnlyElement(providers).getDeclaredConstructor().newInstance();
-                } catch (Exception e) {
-                  LOG.error("Failed to create authorization instance", e);
-                  throw new RuntimeException(e);
-                }
-              });
-    } catch (Exception e) {
-      LOG.error("Failed to load authorization with class loader", e);
-      throw new RuntimeException(e);
+          } catch (Exception e) {
+            LOG.error("Failed to load authorization with class loader", e);
+            throw new RuntimeException(e);
+          }
+        }
+      }
     }
   }
 
@@ -238,9 +232,13 @@ public abstract class BaseCatalog<T extends BaseCatalog>
       ops.close();
       ops = null;
     }
-    if (authorization != null) {
-      authorization.close();
-      authorization = null;
+    if (authorizationPlugin != null) {
+      authorizationPlugin.close();
+      authorizationPlugin = null;
+    }
+    if (catalogCredentialManager != null) {
+      catalogCredentialManager.close();
+      catalogCredentialManager = null;
     }
   }
 
@@ -256,6 +254,17 @@ public abstract class BaseCatalog<T extends BaseCatalog>
     return capability;
   }
 
+  public CatalogCredentialManager catalogCredentialManager() {
+    if (catalogCredentialManager == null) {
+      synchronized (this) {
+        if (catalogCredentialManager == null) {
+          this.catalogCredentialManager = new CatalogCredentialManager(name(), properties());
+        }
+      }
+    }
+    return catalogCredentialManager;
+  }
+
   private CatalogOperations createOps(Map<String, String> conf) {
     String customCatalogOperationClass = conf.get(CATALOG_OPERATION_IMPL);
     return Optional.ofNullable(customCatalogOperationClass)
