@@ -32,16 +32,22 @@ import org.apache.gravitino.file.Fileset;
 import org.apache.gravitino.file.FilesetChange;
 import org.apache.gravitino.listener.api.event.AlterFilesetEvent;
 import org.apache.gravitino.listener.api.event.AlterFilesetFailureEvent;
+import org.apache.gravitino.listener.api.event.AlterFilesetPreEvent;
 import org.apache.gravitino.listener.api.event.CreateFilesetEvent;
 import org.apache.gravitino.listener.api.event.CreateFilesetFailureEvent;
+import org.apache.gravitino.listener.api.event.CreateFilesetPreEvent;
 import org.apache.gravitino.listener.api.event.DropFilesetEvent;
 import org.apache.gravitino.listener.api.event.DropFilesetFailureEvent;
+import org.apache.gravitino.listener.api.event.DropFilesetPreEvent;
 import org.apache.gravitino.listener.api.event.GetFileLocationEvent;
 import org.apache.gravitino.listener.api.event.GetFileLocationFailureEvent;
+import org.apache.gravitino.listener.api.event.GetFileLocationPreEvent;
 import org.apache.gravitino.listener.api.event.ListFilesetEvent;
 import org.apache.gravitino.listener.api.event.ListFilesetFailureEvent;
+import org.apache.gravitino.listener.api.event.ListFilesetPreEvent;
 import org.apache.gravitino.listener.api.event.LoadFilesetEvent;
 import org.apache.gravitino.listener.api.event.LoadFilesetFailureEvent;
+import org.apache.gravitino.listener.api.event.LoadFilesetPreEvent;
 import org.apache.gravitino.listener.api.info.FilesetInfo;
 import org.apache.gravitino.utils.PrincipalUtils;
 
@@ -62,6 +68,7 @@ public class FilesetEventDispatcher implements FilesetDispatcher {
 
   @Override
   public NameIdentifier[] listFilesets(Namespace namespace) throws NoSuchSchemaException {
+    eventBus.dispatchEvent(new ListFilesetPreEvent(PrincipalUtils.getCurrentUserName(), namespace));
     try {
       NameIdentifier[] nameIdentifiers = dispatcher.listFilesets(namespace);
       eventBus.dispatchEvent(new ListFilesetEvent(PrincipalUtils.getCurrentUserName(), namespace));
@@ -75,6 +82,7 @@ public class FilesetEventDispatcher implements FilesetDispatcher {
 
   @Override
   public Fileset loadFileset(NameIdentifier ident) throws NoSuchFilesetException {
+    eventBus.dispatchEvent(new LoadFilesetPreEvent(PrincipalUtils.getCurrentUserName(), ident));
     try {
       Fileset fileset = dispatcher.loadFileset(ident);
       eventBus.dispatchEvent(
@@ -96,6 +104,10 @@ public class FilesetEventDispatcher implements FilesetDispatcher {
       String storageLocation,
       Map<String, String> properties)
       throws NoSuchSchemaException, FilesetAlreadyExistsException {
+    FilesetInfo createFileRequest =
+        new FilesetInfo(ident.name(), comment, type, storageLocation, properties, null);
+    eventBus.dispatchEvent(
+        new CreateFilesetPreEvent(PrincipalUtils.getCurrentUserName(), ident, createFileRequest));
     try {
       Fileset fileset = dispatcher.createFileset(ident, comment, type, storageLocation, properties);
       eventBus.dispatchEvent(
@@ -116,6 +128,8 @@ public class FilesetEventDispatcher implements FilesetDispatcher {
   @Override
   public Fileset alterFileset(NameIdentifier ident, FilesetChange... changes)
       throws NoSuchFilesetException, IllegalArgumentException {
+    eventBus.dispatchEvent(
+        new AlterFilesetPreEvent(PrincipalUtils.getCurrentUserName(), ident, changes));
     try {
       Fileset fileset = dispatcher.alterFileset(ident, changes);
       eventBus.dispatchEvent(
@@ -131,6 +145,7 @@ public class FilesetEventDispatcher implements FilesetDispatcher {
 
   @Override
   public boolean dropFileset(NameIdentifier ident) {
+    eventBus.dispatchEvent(new DropFilesetPreEvent(PrincipalUtils.getCurrentUserName(), ident));
     try {
       boolean isExists = dispatcher.dropFileset(ident);
       eventBus.dispatchEvent(
@@ -146,6 +161,8 @@ public class FilesetEventDispatcher implements FilesetDispatcher {
   @Override
   public String getFileLocation(NameIdentifier ident, String subPath)
       throws NoSuchFilesetException {
+    eventBus.dispatchEvent(
+        new GetFileLocationPreEvent(PrincipalUtils.getCurrentUserName(), ident, subPath));
     try {
       String actualFileLocation = dispatcher.getFileLocation(ident, subPath);
       // get the audit info from the thread local context
