@@ -26,7 +26,7 @@ import org.apache.gravitino.Configs;
 
 public class SQLExceptionConverterFactory {
   private static final Pattern TYPE_PATTERN = Pattern.compile("jdbc:(\\w+):");
-  private static SQLExceptionConverter converter;
+  private static volatile SQLExceptionConverter converter;
 
   private SQLExceptionConverterFactory() {}
 
@@ -56,4 +56,14 @@ public class SQLExceptionConverterFactory {
     Preconditions.checkState(converter != null, "Exception converter is not initialized.");
     return converter;
   }
+
+  public static void close() {
+    if (converter != null) {
+      synchronized (SQLExceptionConverterFactory.class) {
+        if (converter != null) {
+          converter = null;
+        }
+      }
+    }
+  }
 }
