@@ -144,4 +144,14 @@ public class SecurableObjectPostgreSQLProvider extends SecurableObjectBaseSQLPro
         + "ft.fileset_id = sect.metadata_object_id AND sect.type = 'FILESET'"
         + ")";
   }
+
+  @Override
+  public String deleteSecurableObjectsByLegacyTimeline(
+      @Param("legacyTimeline") Long legacyTimeline, @Param("limit") int limit) {
+    return "DELETE FROM "
+        + SECURABLE_OBJECT_TABLE_NAME
+        + " WHERE id IN (SELECT id FROM "
+        + ROLE_TABLE_NAME
+        + " WHERE deleted_at > 0 AND deleted_at < #{legacyTimeline} LIMIT #{limit})";
+  }
 }
