@@ -27,6 +27,7 @@ import org.apache.gravitino.storage.relational.po.CatalogPO;
 import org.apache.gravitino.storage.relational.po.ColumnPO;
 import org.apache.gravitino.storage.relational.po.FilesetPO;
 import org.apache.gravitino.storage.relational.po.MetalakePO;
+import org.apache.gravitino.storage.relational.po.ModelPO;
 import org.apache.gravitino.storage.relational.po.SchemaPO;
 import org.apache.gravitino.storage.relational.po.TablePO;
 import org.apache.gravitino.storage.relational.po.TopicPO;
@@ -49,10 +50,10 @@ public class MetadataObjectService {
       return MetalakeMetaService.getInstance().getMetalakeIdByName(fullName);
     }
 
-    List<String> names = DOT_SPLITTER.splitToList(fullName);
     if (type == MetadataObject.Type.ROLE) {
-      return RoleMetaService.getInstance().getRoleIdByMetalakeIdAndName(metalakeId, names.get(0));
+      return RoleMetaService.getInstance().getRoleIdByMetalakeIdAndName(metalakeId, fullName);
     }
+    List<String> names = DOT_SPLITTER.splitToList(fullName);
 
     long catalogId =
         CatalogMetaService.getInstance().getCatalogIdByMetalakeIdAndName(metalakeId, names.get(0));
@@ -70,6 +71,9 @@ public class MetadataObjectService {
       return FilesetMetaService.getInstance().getFilesetIdBySchemaIdAndName(schemaId, names.get(2));
     } else if (type == MetadataObject.Type.TOPIC) {
       return TopicMetaService.getInstance().getTopicIdBySchemaIdAndName(schemaId, names.get(2));
+    } else if (type == MetadataObject.Type.MODEL) {
+      return ModelMetaService.getInstance()
+          .getModelIdBySchemaIdAndModelName(schemaId, names.get(2));
     }
 
     long tableId =
@@ -174,6 +178,20 @@ public class MetadataObjectService {
           }
           break;
 
+        case MODEL:
+          ModelPO modelPO = ModelMetaService.getInstance().getModelPOById(objectId);
+          if (modelPO != null) {
+            fullName =
+                fullName != null
+                    ? DOT_JOINER.join(modelPO.getModelName(), fullName)
+                    : modelPO.getModelName();
+            objectId = modelPO.getSchemaId();
+            metadataType = MetadataObject.Type.SCHEMA;
+          } else {
+            return null;
+          }
+          break;
+
         case COLUMN:
           ColumnPO columnPO = TableColumnMetaService.getInstance().getColumnPOById(objectId);
           if (columnPO != null) {
