@@ -93,6 +93,16 @@ public class NameIdentifierUtil {
     return NameIdentifier.of(metalake, catalog, schema, table);
   }
 
+  /**
+   * Create the tag {@link NameIdentifier} with the given metalake and tag name.
+   *
+   * @param metalake The metalake name
+   * @param tagName The tag name
+   * @return The created tag {@link NameIdentifier}
+   */
+  public static NameIdentifier ofTag(String metalake, String tagName) {
+    return NameIdentifier.of(NamespaceUtil.ofTag(metalake), tagName);
+  }
   /**
    * Create the column {@link NameIdentifier} with the given metalake, catalog, schema, table and
    * column name.
@@ -139,6 +149,105 @@ public class NameIdentifierUtil {
     return NameIdentifier.of(metalake, catalog, schema, topic);
   }
 
+  /**
+   * Create the model {@link NameIdentifier} with the given metalake, catalog, schema and model
+   * name.
+   *
+   * @param metalake The metalake name
+   * @param catalog The catalog name
+   * @param schema The schema name
+   * @param model The model name
+   * @return The created model {@link NameIdentifier}
+   */
+  public static NameIdentifier ofModel(
+      String metalake, String catalog, String schema, String model) {
+    return NameIdentifier.of(metalake, catalog, schema, model);
+  }
+
+  /**
+   * Create the model {@link NameIdentifier} from the give model version's namespace.
+   *
+   * @param modelVersionNs The model version's namespace
+   * @return The created model {@link NameIdentifier}
+   */
+  public static NameIdentifier toModelIdentifier(Namespace modelVersionNs) {
+    return NameIdentifier.of(modelVersionNs.levels());
+  }
+
+  /**
+   * Create the model {@link NameIdentifier} from the give model version's name identifier.
+   *
+   * @param modelIdent The model version's name identifier
+   * @return The created model {@link NameIdentifier}
+   */
+  public static NameIdentifier toModelIdentifier(NameIdentifier modelIdent) {
+    return NameIdentifier.of(modelIdent.namespace().levels());
+  }
+
+  /**
+   * Create the model version {@link NameIdentifier} with the given metalake, catalog, schema, model
+   * and version.
+   *
+   * @param metalake The metalake name
+   * @param catalog The catalog name
+   * @param schema The schema name
+   * @param model The model name
+   * @param version The model version
+   * @return The created model version {@link NameIdentifier}
+   */
+  public static NameIdentifier ofModelVersion(
+      String metalake, String catalog, String schema, String model, int version) {
+    return NameIdentifier.of(metalake, catalog, schema, model, String.valueOf(version));
+  }
+
+  /**
+   * Create the model version {@link NameIdentifier} with the given metalake, catalog, schema, model
+   * and alias.
+   *
+   * @param metalake The metalake name
+   * @param catalog The catalog name
+   * @param schema The schema name
+   * @param model The model name
+   * @param alias The model version alias
+   * @return The created model version {@link NameIdentifier}
+   */
+  public static NameIdentifier ofModelVersion(
+      String metalake, String catalog, String schema, String model, String alias) {
+    return NameIdentifier.of(metalake, catalog, schema, model, alias);
+  }
+
+  /**
+   * Create the model version {@link NameIdentifier} with the given model identifier and version.
+   *
+   * @param modelIdent The model identifier
+   * @param version The model version
+   * @return The created model version {@link NameIdentifier}
+   */
+  public static NameIdentifier toModelVersionIdentifier(NameIdentifier modelIdent, int version) {
+    return ofModelVersion(
+        modelIdent.namespace().level(0),
+        modelIdent.namespace().level(1),
+        modelIdent.namespace().level(2),
+        modelIdent.name(),
+        version);
+  }
+
+  /**
+   * Create the model version {@link NameIdentifier} with the given model identifier and alias.
+   *
+   * @param modelIdent The model identifier
+   * @param alias The model version alias
+   * @return The created model version {@link NameIdentifier}
+   */
+  public static NameIdentifier toModelVersionIdentifier(NameIdentifier modelIdent, String alias) {
+    return ofModelVersion(
+        modelIdent.namespace().level(0),
+        modelIdent.namespace().level(1),
+        modelIdent.namespace().level(2),
+        modelIdent.name(),
+        alias);
+  }
+
   /**
    * Try to get the catalog {@link NameIdentifier} from the given {@link NameIdentifier}.
    *
@@ -150,7 +259,8 @@ public class NameIdentifierUtil {
   public static NameIdentifier getCatalogIdentifier(NameIdentifier ident)
       throws IllegalNameIdentifierException {
     NameIdentifier.check(
-        ident.name() != null, "The name variable in the NameIdentifier must have value.");
+        ident.name() != null && !ident.name().isEmpty(),
+        "The name variable in the NameIdentifier must have value.");
     Namespace.check(
         ident.namespace() != null && !ident.namespace().isEmpty(),
         "Catalog namespace must be non-null and have 1 level, the input namespace is %s",
@@ -166,6 +276,34 @@ public class NameIdentifierUtil {
     return NameIdentifier.of(allElems.get(0), allElems.get(1));
   }
 
+  /**
+   * Try to get the schema {@link NameIdentifier} from the given {@link NameIdentifier}.
+   *
+   * @param ident The {@link NameIdentifier} to check.
+   * @return The schema {@link NameIdentifier}
+   * @throws IllegalNameIdentifierException If the given {@link NameIdentifier} does not include
+   *     schema name
+   */
+  public static NameIdentifier getSchemaIdentifier(NameIdentifier ident)
+      throws IllegalNameIdentifierException {
+    NameIdentifier.check(
+        ident.name() != null && !ident.name().isEmpty(),
+        "The name variable in the NameIdentifier must have value.");
+    Namespace.check(
+        ident.namespace() != null && !ident.namespace().isEmpty() && ident.namespace().length() > 1,
+        "Schema namespace must be non-null and at least 1 level, the input namespace is %s",
+        ident.namespace());
+
+    List<String> allElems =
+        Stream.concat(Arrays.stream(ident.namespace().levels()), Stream.of(ident.name()))
+            .collect(Collectors.toList());
+    if (allElems.size() < 3) {
+      throw new IllegalNameIdentifierException(
+          "Cannot create a schema NameIdentifier less than three elements.");
+    }
+    return NameIdentifier.of(allElems.get(0), allElems.get(1), allElems.get(2));
+  }
+
   /**
    * Check the given {@link NameIdentifier} is a metalake identifier. Throw an {@link
    * IllegalNameIdentifierException} if it's not.
@@ -245,6 +383,28 @@ public class NameIdentifierUtil {
     NamespaceUtil.checkTopic(ident.namespace());
   }
 
+  /**
+   * Check the given {@link NameIdentifier} is a model identifier. Throw an {@link
+   * IllegalNameIdentifierException} if it's not.
+   *
+   * @param ident The model {@link NameIdentifier} to check.
+   */
+  public static void checkModel(NameIdentifier ident) {
+    NameIdentifier.check(ident != null, "Model identifier must not be null");
+    NamespaceUtil.checkModel(ident.namespace());
+  }
+
+  /**
+   * Check the given {@link NameIdentifier} is a model version identifier. Throw an {@link
+   * IllegalNameIdentifierException} if it's not.
+   *
+   * @param ident The model version {@link NameIdentifier} to check.
+   */
+  public static void checkModelVersion(NameIdentifier ident) {
+    NameIdentifier.check(ident != null, "Model version identifier must not be null");
+    NamespaceUtil.checkModelVersion(ident.namespace());
+  }
+
   /**
    * Check the given condition is true. Throw an {@link IllegalNamespaceException} if it's not.
    *
@@ -309,6 +469,11 @@ public class NameIdentifierUtil {
         String topicParent = dot.join(ident.namespace().level(1), ident.namespace().level(2));
         return MetadataObjects.of(topicParent, ident.name(), MetadataObject.Type.TOPIC);
 
+      case MODEL:
+        checkModel(ident);
+        String modelParent = dot.join(ident.namespace().level(1), ident.namespace().level(2));
+        return MetadataObjects.of(modelParent, ident.name(), MetadataObject.Type.MODEL);
+
       case ROLE:
         AuthorizationUtils.checkRole(ident);
         return MetadataObjects.of(null, ident.name(), MetadataObject.Type.ROLE);
