@@ -27,6 +27,7 @@ import static org.junit.jupiter.api.Assertions.fail;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -53,11 +54,32 @@ import org.apache.gravitino.rel.Table;
 import org.apache.gravitino.rel.types.Types;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.condition.EnabledIf;
 
 public abstract class FlinkCommonIT extends FlinkEnvIT {
 
   protected abstract Catalog currentCatalog();
 
+  protected boolean supportTableOperation() {
+    return true;
+  }
+
+  protected boolean supportColumnOperation() {
+    return true;
+  }
+
+  protected boolean supportSchemaOperationWithCommentAndOptions() {
+    return true;
+  }
+
+  protected boolean supportGetSchemaWithoutCommentAndOption() {
+    return true;
+  }
+
+  protected abstract String getProvider();
+
+  protected abstract boolean supportDropCascade();
+
   @Test
   public void testCreateSchema() {
     doWithCatalog(
@@ -68,6 +90,28 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
             TableResult tableResult = sql("CREATE DATABASE IF NOT EXISTS %s", schema);
             TestUtils.assertTableResult(tableResult, ResultKind.SUCCESS);
             catalog.asSchemas().schemaExists(schema);
+          } finally {
+            catalog.asSchemas().dropSchema(schema, supportDropCascade());
+            Assertions.assertFalse(catalog.asSchemas().schemaExists(schema));
+          }
+        });
+  }
+
+  @Test
+  @EnabledIf("supportGetSchemaWithoutCommentAndOption")
+  public void testGetSchemaWithoutCommentAndOption() {
+    doWithCatalog(
+        currentCatalog(),
+        catalog -> {
+          String schema = "test_get_schema";
+          try {
+            TestUtils.assertTableResult(
+                sql("CREATE DATABASE IF NOT EXISTS %s", schema), ResultKind.SUCCESS);
+            TestUtils.assertTableResult(tableEnv.executeSql("USE " + schema), ResultKind.SUCCESS);
+
+            catalog.asSchemas().schemaExists(schema);
+            Schema loadedSchema = catalog.asSchemas().loadSchema(schema);
+            Assertions.assertEquals(schema, loadedSchema.name());
           } finally {
             catalog.asSchemas().dropSchema(schema, true);
             Assertions.assertFalse(catalog.asSchemas().schemaExists(schema));
@@ -76,7 +120,8 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
   }
 
   @Test
-  public void testGetSchema() {
+  @EnabledIf("supportSchemaOperationWithCommentAndOptions")
+  public void testGetSchemaWithCommentAndOptions() {
     doWithCatalog(
         currentCatalog(),
         catalog -> {
@@ -98,12 +143,11 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
             Schema loadedSchema = catalog.asSchemas().loadSchema(schema);
             Assertions.assertEquals(schema, loadedSchema.name());
             Assertions.assertEquals(comment, loadedSchema.comment());
-            Assertions.assertEquals(2, loadedSchema.properties().size());
             Assertions.assertEquals(propertyValue, loadedSchema.properties().get(propertyKey));
             Assertions.assertEquals(
                 location, loadedSchema.properties().get(HiveConstants.LOCATION));
           } finally {
-            catalog.asSchemas().dropSchema(schema, true);
+            catalog.asSchemas().dropSchema(schema, supportDropCascade());
             Assertions.assertFalse(catalog.asSchemas().schemaExists(schema));
           }
         });
@@ -114,7 +158,6 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
     doWithCatalog(
         currentCatalog(),
         catalog -> {
-          Assertions.assertEquals(1, catalog.asSchemas().listSchemas().length);
           String schema = "test_list_schema";
           String schema2 = "test_list_schema2";
           String schema3 = "test_list_schema3";
@@ -135,22 +178,24 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
                 Row.of(schema3));
 
             String[] schemas = catalog.asSchemas().listSchemas();
+            Arrays.sort(schemas);
             Assertions.assertEquals(4, schemas.length);
             Assertions.assertEquals("default", schemas[0]);
             Assertions.assertEquals(schema, schemas[1]);
             Assertions.assertEquals(schema2, schemas[2]);
             Assertions.assertEquals(schema3, schemas[3]);
           } finally {
-            catalog.asSchemas().dropSchema(schema, true);
-            catalog.asSchemas().dropSchema(schema2, true);
-            catalog.asSchemas().dropSchema(schema3, true);
+            catalog.asSchemas().dropSchema(schema, supportDropCascade());
+            catalog.asSchemas().dropSchema(schema2, supportDropCascade());
+            catalog.asSchemas().dropSchema(schema3, supportDropCascade());
             Assertions.assertEquals(1, catalog.asSchemas().listSchemas().length);
           }
         });
   }
 
   @Test
-  public void testAlterSchema() {
+  @EnabledIf("supportSchemaOperationWithCommentAndOptions")
+  public void testAlterSchemaWithCommentAndOptions() {
     doWithCatalog(
         currentCatalog(),
         catalog -> {
@@ -167,7 +212,6 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
             Schema loadedSchema = catalog.asSchemas().loadSchema(schema);
             Assertions.assertEquals(schema, loadedSchema.name());
             Assertions.assertEquals("test comment", loadedSchema.comment());
-            Assertions.assertEquals(3, loadedSchema.properties().size());
             Assertions.assertEquals("value1", loadedSchema.properties().get("key1"));
             Assertions.assertEquals("value2", loadedSchema.properties().get("key2"));
             Assertions.assertNotNull(loadedSchema.properties().get("location"));
@@ -178,16 +222,16 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
             Schema reloadedSchema = catalog.asSchemas().loadSchema(schema);
             Assertions.assertEquals(schema, reloadedSchema.name());
             Assertions.assertEquals("test comment", reloadedSchema.comment());
-            Assertions.assertEquals(4, reloadedSchema.properties().size());
             Assertions.assertEquals("new-value", reloadedSchema.properties().get("key1"));
             Assertions.assertEquals("value3", reloadedSchema.properties().get("key3"));
           } finally {
-            catalog.asSchemas().dropSchema(schema, true);
+            catalog.asSchemas().dropSchema(schema, supportDropCascade());
           }
         });
   }
 
   @Test
+  @EnabledIf("supportTableOperation")
   public void testCreateSimpleTable() {
     String databaseName = "test_create_no_partition_table_db";
     String tableName = "test_create_no_partition_table";
@@ -232,10 +276,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
               Row.of("A", 1.0),
               Row.of("B", 2.0));
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportTableOperation")
   public void testListTables() {
     String newSchema = "test_list_table_catalog";
     Column[] columns = new Column[] {Column.of("user_id", Types.IntegerType.get(), "USER_ID")};
@@ -264,10 +310,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
               Row.of("test_table1"),
               Row.of("test_table2"));
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportTableOperation")
   public void testDropTable() {
     String databaseName = "test_drop_table_db";
     doWithSchema(
@@ -280,15 +328,15 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
           NameIdentifier identifier = NameIdentifier.of(databaseName, tableName);
           catalog.asTableCatalog().createTable(identifier, columns, "comment1", ImmutableMap.of());
           Assertions.assertTrue(catalog.asTableCatalog().tableExists(identifier));
-
-          TableResult result = sql("DROP TABLE %s", tableName);
-          TestUtils.assertTableResult(result, ResultKind.SUCCESS);
+          sql("DROP TABLE IF EXISTS %s", tableName);
           Assertions.assertFalse(catalog.asTableCatalog().tableExists(identifier));
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportTableOperation")
   public void testGetSimpleTable() {
     String databaseName = "test_get_simple_table";
     Column[] columns =
@@ -338,10 +386,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
             fail(e);
           }
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportColumnOperation")
   public void testRenameColumn() {
     String databaseName = "test_rename_column_db";
     String tableName = "test_rename_column";
@@ -373,10 +423,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
               };
           assertColumns(expected, actual);
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportColumnOperation")
   public void testAlterTableComment() {
     String databaseName = "test_alter_table_comment_database";
     String tableName = "test_alter_table_comment";
@@ -423,6 +475,7 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
                       .asTableCatalog()
                       .loadTable(NameIdentifier.of(databaseName, tableName));
               Assertions.assertEquals(newComment, gravitinoTable.comment());
+
             } catch (DatabaseNotExistException
                 | TableAlreadyExistException
                 | TableNotExistException e) {
@@ -432,10 +485,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
             fail("Catalog doesn't exist");
           }
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportColumnOperation")
   public void testAlterTableAddColumn() {
     String databaseName = "test_alter_table_add_column_db";
     String tableName = "test_alter_table_add_column";
@@ -467,10 +522,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
               };
           assertColumns(expected, actual);
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportColumnOperation")
   public void testAlterTableDropColumn() {
     String databaseName = "test_alter_table_drop_column_db";
     String tableName = "test_alter_table_drop_column";
@@ -497,10 +554,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
               new Column[] {Column.of("order_amount", Types.IntegerType.get(), "ORDER_AMOUNT")};
           assertColumns(expected, actual);
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportColumnOperation")
   public void testAlterColumnTypeAndChangeOrder() {
     String databaseName = "test_alter_table_alter_column_db";
     String tableName = "test_alter_table_rename_column";
@@ -538,10 +597,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
               };
           assertColumns(expected, actual);
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportTableOperation")
   public void testRenameTable() {
     String databaseName = "test_rename_table_db";
     String tableName = "test_rename_table";
@@ -565,10 +626,12 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
           Assertions.assertTrue(
               catalog.asTableCatalog().tableExists(NameIdentifier.of(databaseName, newTableName)));
         },
-        true);
+        true,
+        supportDropCascade());
   }
 
   @Test
+  @EnabledIf("supportTableOperation")
   public void testAlterTableProperties() {
     String databaseName = "test_alter_table_properties_db";
     String tableName = "test_alter_table_properties";
@@ -607,6 +670,7 @@ public abstract class FlinkCommonIT extends FlinkEnvIT {
           Assertions.assertEquals("value1", properties.get("key"));
           Assertions.assertNull(properties.get("key2"));
         },
-        true);
+        true,
+        supportDropCascade());
   }
 }
