@@ -72,7 +72,7 @@ public class FlinkHiveCatalogIT extends FlinkCommonIT {
   private static org.apache.gravitino.Catalog hiveCatalog;
 
   @BeforeAll
-  static void hiveStartUp() {
+  void hiveStartUp() {
     initDefaultHiveCatalog();
   }
 
@@ -82,13 +82,13 @@ public class FlinkHiveCatalogIT extends FlinkCommonIT {
     metalake.dropCatalog(DEFAULT_HIVE_CATALOG, true);
   }
 
-  protected static void initDefaultHiveCatalog() {
+  protected void initDefaultHiveCatalog() {
     Preconditions.checkNotNull(metalake);
     hiveCatalog =
         metalake.createCatalog(
             DEFAULT_HIVE_CATALOG,
             org.apache.gravitino.Catalog.Type.RELATIONAL,
-            "hive",
+            getProvider(),
             null,
             ImmutableMap.of("metastore.uris", hiveMetastoreUri));
   }
@@ -582,8 +582,23 @@ public class FlinkHiveCatalogIT extends FlinkCommonIT {
         true);
   }
 
+  @Override
+  protected Map<String, String> getCreateSchemaProps(String schemaName) {
+    return ImmutableMap.of("location", warehouse + "/" + schemaName);
+  }
+
   @Override
   protected org.apache.gravitino.Catalog currentCatalog() {
     return hiveCatalog;
   }
+
+  @Override
+  protected String getProvider() {
+    return "hive";
+  }
+
+  @Override
+  protected boolean supportDropCascade() {
+    return true;
+  }
 }
