@@ -32,6 +32,8 @@ import org.apache.gravitino.exceptions.InUseException;
 import org.apache.gravitino.exceptions.MetalakeAlreadyExistsException;
 import org.apache.gravitino.exceptions.MetalakeInUseException;
 import org.apache.gravitino.exceptions.MetalakeNotInUseException;
+import org.apache.gravitino.exceptions.ModelAlreadyExistsException;
+import org.apache.gravitino.exceptions.ModelVersionAliasesAlreadyExistException;
 import org.apache.gravitino.exceptions.NoSuchMetalakeException;
 import org.apache.gravitino.exceptions.NonEmptyCatalogException;
 import org.apache.gravitino.exceptions.NonEmptyMetalakeException;
@@ -121,6 +123,16 @@ public class ExceptionHandlers {
     return TagExceptionHandler.INSTANCE.handle(op, tag, parent, e);
   }
 
+  public static Response handleCredentialException(
+      OperationType op, String metadataObjectName, Exception e) {
+    return CredentialExceptionHandler.INSTANCE.handle(op, metadataObjectName, "", e);
+  }
+
+  public static Response handleModelException(
+      OperationType op, String model, String schema, Exception e) {
+    return ModelExceptionHandler.INSTANCE.handle(op, model, schema, e);
+  }
+
   public static Response handleTestConnectionException(Exception e) {
     ErrorResponse response;
     if (e instanceof IllegalArgumentException) {
@@ -369,6 +381,7 @@ public class ExceptionHandlers {
   }
 
   private static class FilesetExceptionHandler extends BaseExceptionHandler {
+
     private static final ExceptionHandler INSTANCE = new FilesetExceptionHandler();
 
     private static String getFilesetErrorMsg(
@@ -520,6 +533,7 @@ public class ExceptionHandlers {
   }
 
   private static class TopicExceptionHandler extends BaseExceptionHandler {
+
     private static final ExceptionHandler INSTANCE = new TopicExceptionHandler();
 
     private static String getTopicErrorMsg(
@@ -558,6 +572,7 @@ public class ExceptionHandlers {
 
   private static class UserPermissionOperationExceptionHandler
       extends BasePermissionExceptionHandler {
+
     private static final ExceptionHandler INSTANCE = new UserPermissionOperationExceptionHandler();
 
     @Override
@@ -622,6 +637,35 @@ public class ExceptionHandlers {
     }
   }
 
+  private static class CredentialExceptionHandler extends BaseExceptionHandler {
+
+    private static final ExceptionHandler INSTANCE = new CredentialExceptionHandler();
+
+    private static String getCredentialErrorMsg(String parent, String reason) {
+      return String.format(
+          "Failed to get credentials under object [%s], reason [%s]", parent, reason);
+    }
+
+    @Override
+    public Response handle(OperationType op, String credential, String parent, Exception e) {
+      String errorMsg = getCredentialErrorMsg(parent, getErrorMsg(e));
+      LOG.warn(errorMsg, e);
+
+      if (e instanceof IllegalArgumentException) {
+        return Utils.illegalArguments(errorMsg, e);
+
+      } else if (e instanceof NotFoundException) {
+        return Utils.notFound(errorMsg, e);
+
+      } else if (e instanceof NotInUseException) {
+        return Utils.notInUse(errorMsg, e);
+
+      } else {
+        return super.handle(op, credential, parent, e);
+      }
+    }
+  }
+
   private static class TagExceptionHandler extends BaseExceptionHandler {
 
     private static final ExceptionHandler INSTANCE = new TagExceptionHandler();
@@ -661,6 +705,7 @@ public class ExceptionHandlers {
   }
 
   private static class OwnerExceptionHandler extends BaseExceptionHandler {
+
     private static final ExceptionHandler INSTANCE = new OwnerExceptionHandler();
 
     private static String getOwnerErrorMsg(
@@ -691,6 +736,44 @@ public class ExceptionHandlers {
     }
   }
 
+  private static class ModelExceptionHandler extends BaseExceptionHandler {
+    private static final ExceptionHandler INSTANCE = new ModelExceptionHandler();
+
+    private static String getModelErrorMsg(
+        String model, String operation, String schema, String reason) {
+      return String.format(
+          "Failed to operate model(s)%s operation [%s] under schema [%s], reason [%s]",
+          model, operation, schema, reason);
+    }
+
+    @Override
+    public Response handle(OperationType op, String model, String schema, Exception e) {
+      String formatted = StringUtil.isBlank(model) ? "" : " [" + model + "]";
+      String errorMsg = getModelErrorMsg(formatted, op.name(), schema, getErrorMsg(e));
+      LOG.warn(errorMsg, e);
+
+      if (e instanceof IllegalArgumentException) {
+        return Utils.illegalArguments(errorMsg, e);
+
+      } else if (e instanceof NotFoundException) {
+        return Utils.notFound(errorMsg, e);
+
+      } else if (e instanceof ModelAlreadyExistsException
+          || e instanceof ModelVersionAliasesAlreadyExistException) {
+        return Utils.alreadyExists(errorMsg, e);
+
+      } else if (e instanceof ForbiddenException) {
+        return Utils.forbidden(errorMsg, e);
+
+      } else if (e instanceof NotInUseException) {
+        return Utils.notInUse(errorMsg, e);
+
+      } else {
+        return super.handle(op, model, schema, e);
+      }
+    }
+  }
+
   @VisibleForTesting
   static class BaseExceptionHandler extends ExceptionHandler {
 
