@@ -18,18 +18,22 @@
  */
 package org.apache.gravitino.spark.connector.version;
 
-import org.apache.gravitino.spark.connector.hive.GravitinoHiveCatalogSpark33;
-import org.apache.gravitino.spark.connector.iceberg.GravitinoIcebergCatalogSpark33;
+import org.apache.gravitino.spark.connector.hive.GravitinoHiveCatalogSpark35;
+import org.apache.gravitino.spark.connector.iceberg.GravitinoIcebergCatalogSpark35;
+import org.apache.gravitino.spark.connector.paimon.GravitinoPaimonCatalogSpark35;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
 public class TestCatalogNameAdaptor {
   @Test
-  void testSpark33() {
+  void testSpark35() {
     String hiveCatalogName = CatalogNameAdaptor.getCatalogName("hive");
-    Assertions.assertEquals(GravitinoHiveCatalogSpark33.class.getName(), hiveCatalogName);
+    Assertions.assertEquals(GravitinoHiveCatalogSpark35.class.getName(), hiveCatalogName);
 
     String icebergCatalogName = CatalogNameAdaptor.getCatalogName("lakehouse-iceberg");
-    Assertions.assertEquals(GravitinoIcebergCatalogSpark33.class.getName(), icebergCatalogName);
+    Assertions.assertEquals(GravitinoIcebergCatalogSpark35.class.getName(), icebergCatalogName);
+
+    String paimonCatalogName = CatalogNameAdaptor.getCatalogName("lakehouse-paimon");
+    Assertions.assertEquals(GravitinoPaimonCatalogSpark35.class.getName(), paimonCatalogName);
   }
 }
