@@ -30,7 +30,6 @@ import org.apache.gravitino.Catalog;
 import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.client.GravitinoAdminClient;
 import org.apache.gravitino.client.GravitinoMetalake;
-import org.apache.gravitino.file.Fileset;
 import org.apache.gravitino.integration.test.container.ContainerSuite;
 import org.apache.gravitino.integration.test.container.TrinoITContainers;
 import org.apache.gravitino.integration.test.web.ui.pages.CatalogsPage;
@@ -93,6 +92,7 @@ public class CatalogsPageTest extends BaseWebIT {
   private static final String FILESET_NAME = "fileset1";
   private static final String TABLE_NAME = "table1";
   private static final String TABLE_NAME_2 = "table2";
+  private static final String TABLE_NAME_3 = "table3";
   private static final String COLUMN_NAME = "column";
   private static final String COLUMN_NAME_2 = "column_2";
   private static final String PROPERTIES_KEY1 = "key1";
@@ -131,21 +131,6 @@ public class CatalogsPageTest extends BaseWebIT {
     catalogsPage = new CatalogsPage(driver);
   }
 
-  /**
-   * Create the specified schema
-   *
-   * @param metalakeName The name of the Metalake where the schema will be created.
-   * @param catalogName The name of the Catalog where the schema will be created.
-   * @param schemaName The name of the Schema where the schema will be created.
-   */
-  void createSchema(String metalakeName, String catalogName, String schemaName) {
-    Map<String, String> properties = Maps.newHashMap();
-    properties.put(PROPERTIES_KEY1, PROPERTIES_VALUE1);
-    GravitinoMetalake metalake = gravitinoClient.loadMetalake(metalakeName);
-    Catalog catalog = metalake.loadCatalog(catalogName);
-    catalog.asSchemas().createSchema(schemaName, "comment", properties);
-  }
-
   /**
    * Creates a table with a single column in the specified Metalake, Catalog, Schema, and Table.
    *
@@ -215,31 +200,6 @@ public class CatalogsPageTest extends BaseWebIT {
     return defaultBaseLocation(schemaName) + "/" + filesetName;
   }
 
-  /**
-   * Creates a fileset within the specified Metalake, Catalog, Schema, and Fileset names.
-   *
-   * @param metalakeName The name of the Metalake.
-   * @param catalogName The name of the Catalog.
-   * @param schemaName The name of the Schema.
-   * @param filesetName The name of the Fileset.
-   */
-  void createFileset(
-      String metalakeName, String catalogName, String schemaName, String filesetName) {
-    Map<String, String> properties = Maps.newHashMap();
-    properties.put(PROPERTIES_KEY1, PROPERTIES_VALUE1);
-    String storageLocation = storageLocation(schemaName, filesetName);
-    GravitinoMetalake metalake = gravitinoClient.loadMetalake(metalakeName);
-    Catalog catalog_fileset = metalake.loadCatalog(catalogName);
-    catalog_fileset
-        .asFilesetCatalog()
-        .createFileset(
-            NameIdentifier.of(schemaName, filesetName),
-            "comment",
-            Fileset.Type.MANAGED,
-            storageLocation,
-            properties);
-  }
-
   @AfterAll
   public static void after() {
     try {
@@ -270,7 +230,7 @@ public class CatalogsPageTest extends BaseWebIT {
     clickAndWait(catalogsPage.handleSubmitCatalogBtn);
     // delete catalog
     catalogsPage.clickInUseSwitch(DEFAULT_CATALOG_NAME);
-    catalogsPage.clickDeleteCatalogBtn(DEFAULT_CATALOG_NAME);
+    catalogsPage.clickDeleteBtn(DEFAULT_CATALOG_NAME);
     clickAndWait(catalogsPage.confirmDeleteBtn);
     Assertions.assertTrue(catalogsPage.verifyEmptyTableData());
   }
@@ -284,9 +244,9 @@ public class CatalogsPageTest extends BaseWebIT {
     catalogsPage.setCatalogCommentField("catalog comment");
     catalogsPage.setCatalogFixedProp("metastore.uris", hiveMetastoreUri);
     catalogsPage.addCatalogPropsBtn.click();
-    catalogsPage.setCatalogPropsAt(1, "key1", "value1");
+    catalogsPage.setPropsAt(1, "key1", "value1");
     catalogsPage.addCatalogPropsBtn.click();
-    catalogsPage.setCatalogPropsAt(2, "key2", "value2");
+    catalogsPage.setPropsAt(2, "key2", "value2");
     clickAndWait(catalogsPage.handleSubmitCatalogBtn);
     // load catalog
     GravitinoMetalake metalake = gravitinoClient.loadMetalake(METALAKE_NAME);
@@ -583,6 +543,33 @@ public class CatalogsPageTest extends BaseWebIT {
 
   @Test
   @Order(19)
+  public void testCreateTableByUI() throws InterruptedException {
+    String schemaNode =
+        String.format(
+            "{{%s}}{{%s}}{{%s}}{{%s}}",
+            METALAKE_NAME, MODIFIED_HIVE_CATALOG_NAME, CATALOG_TYPE_RELATIONAL, SCHEMA_NAME);
+    catalogsPage.clickTreeNode(schemaNode);
+    // 1. create table in hive catalog without partition/sort order/distribution
+    clickAndWait(catalogsPage.createTableBtn);
+    catalogsPage.setTableNameField(TABLE_NAME_3);
+    catalogsPage.setTableCommentField("table comment for ui");
+    catalogsPage.setTableColumnsAt(0, COLUMN_NAME, "byte");
+    clickAndWait(catalogsPage.handleSubmitTableBtn);
+    Assertions.assertTrue(catalogsPage.verifyShowDataItemInList(TABLE_NAME_3, false));
+  }
+
+  @Test
+  @Order(20)
+  public void testDropTableByUI() throws InterruptedException {
+    // delete table of hive catalog
+    catalogsPage.clickDeleteBtn(TABLE_NAME_3);
+    clickAndWait(catalogsPage.confirmDeleteBtn);
+    // verify table list without table name 3
+    Assertions.assertTrue(catalogsPage.verifyNoDataItemInList(TABLE_NAME_3, false));
+  }
+
+  @Test
+  @Order(21)
   public void testOtherRelationalCatalogTreeNode() throws InterruptedException {
     String icebergNode =
         String.format(
@@ -602,7 +589,7 @@ public class CatalogsPageTest extends BaseWebIT {
   }
 
   @Test
-  @Order(20)
+  @Order(22)
   public void testSelectMetalake() throws InterruptedException {
     catalogsPage.metalakeSelectChange(METALAKE_SELECT_NAME);
     Assertions.assertTrue(catalogsPage.verifyEmptyTableData());
@@ -612,16 +599,18 @@ public class CatalogsPageTest extends BaseWebIT {
   }
 
   @Test
-  @Order(21)
-  public void testFilesetCatalogTreeNode() throws InterruptedException {
-    // 1. create schema and fileset of fileset catalog
-    createSchema(METALAKE_NAME, FILESET_CATALOG_NAME, SCHEMA_NAME_FILESET);
-    createFileset(METALAKE_NAME, FILESET_CATALOG_NAME, SCHEMA_NAME_FILESET, FILESET_NAME);
-    // 2. click fileset catalog tree node
+  @Order(23)
+  public void testCreateFilesetSchema() throws InterruptedException {
+    // 1. click fileset catalog tree node
     String filesetCatalogNode =
         String.format(
             "{{%s}}{{%s}}{{%s}}", METALAKE_NAME, FILESET_CATALOG_NAME, CATALOG_TYPE_FILESET);
     catalogsPage.clickTreeNode(filesetCatalogNode);
+    // 2. click create schema button
+    clickAndWait(catalogsPage.createSchemaBtn);
+    catalogsPage.setSchemaNameField(SCHEMA_NAME_FILESET);
+    catalogsPage.setCatalogCommentField("fileset schema comment");
+    clickAndWait(catalogsPage.handleSubmitSchemaBtn);
     // 3. verify show table title、 schema name and tree node
     Assertions.assertTrue(catalogsPage.verifyShowTableTitle(CATALOG_TABLE_TITLE));
     Assertions.assertTrue(catalogsPage.verifyShowDataItemInList(SCHEMA_NAME_FILESET, false));
@@ -634,16 +623,30 @@ public class CatalogsPageTest extends BaseWebIT {
             FILESET_CATALOG_NAME,
             SCHEMA_NAME_FILESET);
     Assertions.assertTrue(catalogsPage.verifyTreeNodes(treeNodes));
-    // 4. click schema tree node
+  }
+
+  @Test
+  @Order(24)
+  public void testCreateFileset() throws InterruptedException {
+    // 1. click schema tree node
     String filesetSchemaNode =
         String.format(
             "{{%s}}{{%s}}{{%s}}{{%s}}",
             METALAKE_NAME, FILESET_CATALOG_NAME, CATALOG_TYPE_FILESET, SCHEMA_NAME_FILESET);
     catalogsPage.clickTreeNode(filesetSchemaNode);
-    // 5. verify show table title、 fileset name and tree node
+    // 2. create fileset
+    clickAndWait(catalogsPage.createFilesetBtn);
+    catalogsPage.setFilesetNameField(FILESET_NAME);
+    String storageLocation = storageLocation(SCHEMA_NAME_FILESET, FILESET_NAME);
+    catalogsPage.setFilesetStorageLocationField(storageLocation);
+    catalogsPage.setFilesetCommentField("fileset comment");
+    catalogsPage.addFilesetPropsBtn.click();
+    catalogsPage.setPropsAt(0, PROPERTIES_KEY1, PROPERTIES_VALUE1);
+    clickAndWait(catalogsPage.handleSubmitFilesetBtn);
+    // 3. verify show table title、 fileset name and tree node
     Assertions.assertTrue(catalogsPage.verifyShowTableTitle(SCHEMA_FILESET_TITLE));
     Assertions.assertTrue(catalogsPage.verifyShowDataItemInList(FILESET_NAME, false));
-    treeNodes =
+    List<String> treeNodes =
         Arrays.asList(
             MODIFIED_HIVE_CATALOG_NAME,
             ICEBERG_CATALOG_NAME,
@@ -653,7 +656,7 @@ public class CatalogsPageTest extends BaseWebIT {
             SCHEMA_NAME_FILESET,
             FILESET_NAME);
     Assertions.assertTrue(catalogsPage.verifyTreeNodes(treeNodes));
-    // 6. click fileset tree node
+    // 4. click fileset tree node
     String filesetNode =
         String.format(
             "{{%s}}{{%s}}{{%s}}{{%s}}{{%s}}",
@@ -663,7 +666,7 @@ public class CatalogsPageTest extends BaseWebIT {
             SCHEMA_NAME_FILESET,
             FILESET_NAME);
     catalogsPage.clickTreeNode(filesetNode);
-    // 7. verify show tab details
+    // 5. verify show tab details
     Assertions.assertTrue(catalogsPage.verifyShowDetailsContent());
     Assertions.assertTrue(
         catalogsPage.verifyShowPropertiesItemInList(
@@ -674,7 +677,7 @@ public class CatalogsPageTest extends BaseWebIT {
   }
 
   @Test
-  @Order(22)
+  @Order(25)
   public void testBackHomePage() throws InterruptedException {
     clickAndWait(catalogsPage.backHomeBtn);
     Assertions.assertTrue(catalogsPage.verifyBackHomePage());
