@@ -46,7 +46,7 @@ import {
   updateSchemaApi,
   deleteSchemaApi
 } from '@/lib/api/schemas'
-import { getTablesApi, getTableDetailsApi } from '@/lib/api/tables'
+import { getTablesApi, getTableDetailsApi, createTableApi, updateTableApi, deleteTableApi } from '@/lib/api/tables'
 import {
   getFilesetsApi,
   getFilesetDetailsApi,
@@ -54,7 +54,18 @@ import {
   updateFilesetApi,
   deleteFilesetApi
 } from '@/lib/api/filesets'
-import { getTopicsApi, getTopicDetailsApi } from '@/lib/api/topics'
+import { getTopicsApi, getTopicDetailsApi, createTopicApi, updateTopicApi, deleteTopicApi } from '@/lib/api/topics'
+import {
+  getModelsApi,
+  getModelDetailsApi,
+  registerModelApi,
+  updateModelApi,
+  deleteModelApi,
+  getModelVersionsApi,
+  getVersionDetailsApi,
+  linkVersionApi,
+  deleteVersionApi
+} from '@/lib/api/models'
 
 export const fetchMetalakes = createAsyncThunk('appMetalakes/fetchMetalakes', async (params, { getState }) => {
   const [err, res] = await to(getMetalakesApi())
@@ -116,7 +127,7 @@ export const setIntoTreeNodeWithFetch = createAsyncThunk(
     }
 
     const pathArr = extractPlaceholder(key)
-    const [metalake, catalog, type, schema] = pathArr
+    const [metalake, catalog, type, schema, entity] = pathArr
 
     if (pathArr.length === 1) {
       const [err, res] = await to(getCatalogsApi({ metalake }))
@@ -250,6 +261,27 @@ export const setIntoTreeNodeWithFetch = createAsyncThunk(
           isLeaf: true
         }
       })
+    } else if (pathArr.length === 4 && type === 'model') {
+      const [err, res] = await to(getModelsApi({ metalake, catalog, schema }))
+
+      if (err || !res) {
+        throw new Error(err)
+      }
+
+      const { identifiers = [] } = res
+
+      result.data = identifiers.map(modelItem => {
+        return {
+          ...modelItem,
+          node: 'model',
+          id: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${modelItem.name}}}`,
+          key: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${modelItem.name}}}`,
+          path: `?${new URLSearchParams({ metalake, catalog, type, schema, model: modelItem.name }).toString()}`,
+          name: modelItem.name,
+          title: modelItem.name,
+          isLeaf: true
+        }
+      })
     }
 
     return result
@@ -602,7 +634,7 @@ export const updateSchema = createAsyncThunk(
     }
     dispatch(fetchSchemas({ metalake, catalog, type, init: true }))
 
-    return res.catalog
+    return res.schema
   }
 )
 
@@ -802,6 +834,67 @@ export const getTableDetails = createAsyncThunk(
   }
 )
 
+export const createTable = createAsyncThunk(
+  'appMetalakes/createTable',
+  async ({ data, metalake, catalog, type, schema }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(createTableApi({ data, metalake, catalog, schema }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      return { err: true }
+    }
+
+    const { table: tableItem } = res
+
+    const tableData = {
+      ...tableItem,
+      node: 'table',
+      id: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${tableItem.name}}}`,
+      key: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${tableItem.name}}}`,
+      path: `?${new URLSearchParams({ metalake, catalog, type, schema, table: tableItem.name }).toString()}`,
+      name: tableItem.name,
+      title: tableItem.name,
+      tables: [],
+      children: []
+    }
+
+    dispatch(fetchTables({ metalake, catalog, schema, type, init: true }))
+
+    return tableData
+  }
+)
+
+export const updateTable = createAsyncThunk(
+  'appMetalakes/updateTable',
+  async ({ metalake, catalog, type, schema, table, data }, { dispatch }) => {
+    const [err, res] = await to(updateTableApi({ metalake, catalog, schema, table, data }))
+    if (err || !res) {
+      return { err: true }
+    }
+    dispatch(fetchTables({ metalake, catalog, type, schema, init: true }))
+
+    return res.table
+  }
+)
+
+export const deleteTable = createAsyncThunk(
+  'appMetalakes/deleteTable',
+  async ({ metalake, catalog, type, schema, table }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(deleteTableApi({ metalake, catalog, schema, table }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      throw new Error(err)
+    }
+
+    dispatch(fetchTables({ metalake, catalog, type, schema, page: 'schemas', init: true }))
+
+    return res
+  }
+)
+
 export const fetchFilesets = createAsyncThunk(
   'appMetalakes/fetchFilesets',
   async ({ init, page, metalake, catalog, schema }, { getState, dispatch }) => {
@@ -932,7 +1025,7 @@ export const updateFileset = createAsyncThunk(
     }
     dispatch(fetchFilesets({ metalake, catalog, type, schema, init: true }))
 
-    return res.catalog
+    return res.fileset
   }
 )
 
@@ -1043,6 +1136,309 @@ export const getTopicDetails = createAsyncThunk(
   }
 )
 
+export const createTopic = createAsyncThunk(
+  'appMetalakes/createTopic',
+  async ({ data, metalake, catalog, type, schema }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(createTopicApi({ data, metalake, catalog, schema }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      return { err: true }
+    }
+
+    const { topic: topicItem } = res
+
+    const topicData = {
+      ...topicItem,
+      node: 'topic',
+      id: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${topicItem.name}}}`,
+      key: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${topicItem.name}}}`,
+      path: `?${new URLSearchParams({ metalake, catalog, type, schema, topic: topicItem.name }).toString()}`,
+      name: topicItem.name,
+      title: topicItem.name,
+      tables: [],
+      children: []
+    }
+
+    dispatch(fetchTopics({ metalake, catalog, schema, type, init: true }))
+
+    return topicData
+  }
+)
+
+export const updateTopic = createAsyncThunk(
+  'appMetalakes/updateTopic',
+  async ({ metalake, catalog, type, schema, topic, data }, { dispatch }) => {
+    const [err, res] = await to(updateTopicApi({ metalake, catalog, schema, topic, data }))
+    if (err || !res) {
+      return { err: true }
+    }
+    dispatch(fetchTopics({ metalake, catalog, type, schema, init: true }))
+
+    return res.topic
+  }
+)
+
+export const deleteTopic = createAsyncThunk(
+  'appMetalakes/deleteTopic',
+  async ({ metalake, catalog, type, schema, topic }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(deleteTopicApi({ metalake, catalog, schema, topic }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      throw new Error(err)
+    }
+
+    dispatch(fetchTopics({ metalake, catalog, type, schema, page: 'topics', init: true }))
+
+    return res
+  }
+)
+
+export const fetchModels = createAsyncThunk(
+  'appMetalakes/fetchModels',
+  async ({ init, page, metalake, catalog, schema }, { getState, dispatch }) => {
+    if (init) {
+      dispatch(setTableLoading(true))
+    }
+
+    const [err, res] = await to(getModelsApi({ metalake, catalog, schema }))
+    dispatch(setTableLoading(false))
+
+    if (init && (err || !res)) {
+      dispatch(resetTableData())
+      throw new Error(err)
+    }
+
+    const { identifiers = [] } = res
+
+    const models = identifiers.map(model => {
+      return {
+        ...model,
+        node: 'model',
+        id: `{{${metalake}}}{{${catalog}}}{{${'model'}}}{{${schema}}}{{${model.name}}}`,
+        key: `{{${metalake}}}{{${catalog}}}{{${'model'}}}{{${schema}}}{{${model.name}}}`,
+        path: `?${new URLSearchParams({
+          metalake,
+          catalog,
+          type: 'model',
+          schema,
+          model: model.name
+        }).toString()}`,
+        name: model.name,
+        title: model.name,
+        isLeaf: true
+      }
+    })
+
+    if (init && getState().metalakes.loadedNodes.includes(`{{${metalake}}}{{${catalog}}}{{${'model'}}}{{${schema}}}`)) {
+      dispatch(
+        setIntoTreeNodes({
+          key: `{{${metalake}}}{{${catalog}}}{{${'model'}}}{{${schema}}}`,
+          data: models,
+          tree: getState().metalakes.metalakeTree
+        })
+      )
+    }
+
+    dispatch(
+      setExpandedNodes([
+        `{{${metalake}}}`,
+        `{{${metalake}}}{{${catalog}}}{{${'model'}}}`,
+        `{{${metalake}}}{{${catalog}}}{{${'model'}}}{{${schema}}}`
+      ])
+    )
+
+    return { models, page, init }
+  }
+)
+
+export const getModelDetails = createAsyncThunk(
+  'appMetalakes/getModelDetails',
+  async ({ init, metalake, catalog, schema, model }, { getState, dispatch }) => {
+    const [err, res] = await to(getModelDetailsApi({ metalake, catalog, schema, model }))
+
+    if (err || !res) {
+      throw new Error(err)
+    }
+
+    const { model: resModel } = res
+
+    return resModel
+  }
+)
+
+export const registerModel = createAsyncThunk(
+  'appMetalakes/registerModel',
+  async ({ data, metalake, catalog, type, schema }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(registerModelApi({ data, metalake, catalog, schema }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      return { err: true }
+    }
+
+    const { model: modelItem } = res
+
+    const modelData = {
+      ...modelItem,
+      node: 'model',
+      id: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${modelItem.name}}}`,
+      key: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${modelItem.name}}}`,
+      path: `?${new URLSearchParams({ metalake, catalog, type, schema, model: modelItem.name }).toString()}`,
+      name: modelItem.name,
+      title: modelItem.name,
+      tables: [],
+      children: []
+    }
+
+    dispatch(fetchModels({ metalake, catalog, schema, type, init: true }))
+
+    return modelData
+  }
+)
+
+export const updateModel = createAsyncThunk(
+  'appMetalakes/updateModel',
+  async ({ metalake, catalog, type, schema, model, data }, { dispatch }) => {
+    const [err, res] = await to(updateTopicApi({ metalake, catalog, schema, model, data }))
+    if (err || !res) {
+      return { err: true }
+    }
+    dispatch(fetchModels({ metalake, catalog, type, schema, init: true }))
+
+    return res.model
+  }
+)
+
+export const deleteModel = createAsyncThunk(
+  'appMetalakes/deleteModel',
+  async ({ metalake, catalog, type, schema, model }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(deleteModelApi({ metalake, catalog, schema, model }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      throw new Error(err)
+    }
+
+    dispatch(fetchModels({ metalake, catalog, type, schema, page: 'models', init: true }))
+
+    return res
+  }
+)
+
+export const fetchModelVersions = createAsyncThunk(
+  'appMetalakes/fetchModelVersions',
+  async ({ init, page, metalake, catalog, schema, model }, { getState, dispatch }) => {
+    if (init) {
+      dispatch(setTableLoading(true))
+    }
+
+    const [err, res] = await to(getModelVersionsApi({ metalake, catalog, schema, model }))
+    dispatch(setTableLoading(false))
+
+    if (init && (err || !res)) {
+      dispatch(resetTableData())
+      throw new Error(err)
+    }
+
+    const { versions = [] } = res
+
+    const versionsData = versions.map(version => {
+      return {
+        node: 'version',
+        id: `{{${metalake}}}{{${catalog}}}{{${'model'}}}{{${schema}}}{{${model}}}{{${version}}}`,
+        key: `{{${metalake}}}{{${catalog}}}{{${'model'}}}{{${schema}}}{{${model}}}{{${version}}}`,
+        path: `?${new URLSearchParams({
+          metalake,
+          catalog,
+          type: 'model',
+          schema,
+          model,
+          version
+        }).toString()}`,
+        name: version,
+        title: version,
+        isLeaf: true
+      }
+    })
+
+    return { versions: versionsData, page, init }
+  }
+)
+
+export const getVersionDetails = createAsyncThunk(
+  'appMetalakes/getVersionDetails',
+  async ({ init, metalake, catalog, schema, model, version }, { getState, dispatch }) => {
+    dispatch(resetTableData())
+    if (init) {
+      dispatch(setTableLoading(true))
+    }
+    const [err, res] = await to(getVersionDetailsApi({ metalake, catalog, schema, model, version }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      dispatch(resetTableData())
+      throw new Error(err)
+    }
+
+    const { modelVersion } = res
+
+    return modelVersion
+  }
+)
+
+export const linkVersion = createAsyncThunk(
+  'appMetalakes/linkVersion',
+  async ({ data, metalake, catalog, type, schema, model }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(linkVersionApi({ data, metalake, catalog, schema, model }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      return { err: true }
+    }
+
+    const { version: versionItem } = res
+
+    const versionData = {
+      node: 'version',
+      id: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${model}}}{{${versionItem}}}`,
+      key: `{{${metalake}}}{{${catalog}}}{{${type}}}{{${schema}}}{{${model}}}{{${versionItem}}}`,
+      path: `?${new URLSearchParams({ metalake, catalog, type, schema, version: versionItem }).toString()}`,
+      name: versionItem,
+      title: versionItem,
+      tables: [],
+      children: []
+    }
+
+    dispatch(fetchModelVersions({ metalake, catalog, schema, type, model, init: true }))
+
+    return versionData
+  }
+)
+
+export const deleteVersion = createAsyncThunk(
+  'appMetalakes/deleteVersion',
+  async ({ metalake, catalog, type, schema, model, version }, { dispatch }) => {
+    dispatch(setTableLoading(true))
+    const [err, res] = await to(deleteVersionApi({ metalake, catalog, schema, model, version }))
+    dispatch(setTableLoading(false))
+
+    if (err || !res) {
+      throw new Error(err)
+    }
+
+    dispatch(fetchModelVersions({ metalake, catalog, type, schema, model, page: 'versions', init: true }))
+
+    return res
+  }
+)
+
 export const appMetalakesSlice = createSlice({
   name: 'appMetalakes',
   initialState: {
@@ -1056,6 +1452,8 @@ export const appMetalakesSlice = createSlice({
     columns: [],
     filesets: [],
     topics: [],
+    models: [],
+    versions: [],
     metalakeTree: [],
     loadedNodes: [],
     selectedNodes: [],
@@ -1110,6 +1508,8 @@ export const appMetalakesSlice = createSlice({
       state.columns = []
       state.filesets = []
       state.topics = []
+      state.models = []
+      state.versions = []
     },
     setTableLoading(state, action) {
       state.tableLoading = action.payload
@@ -1285,6 +1685,21 @@ export const appMetalakesSlice = createSlice({
         toast.error(action.error.message)
       }
     })
+    builder.addCase(createTable.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(updateTable.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(deleteTable.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
     builder.addCase(fetchFilesets.fulfilled, (state, action) => {
       state.filesets = action.payload.filesets
       if (action.payload.init) {
@@ -1305,6 +1720,21 @@ export const appMetalakesSlice = createSlice({
         toast.error(action.error.message)
       }
     })
+    builder.addCase(createFileset.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(updateFileset.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(deleteFileset.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
     builder.addCase(fetchTopics.fulfilled, (state, action) => {
       state.topics = action.payload.topics
       if (action.payload.init) {
@@ -1325,6 +1755,79 @@ export const appMetalakesSlice = createSlice({
         toast.error(action.error.message)
       }
     })
+    builder.addCase(createTopic.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(updateTopic.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(deleteTopic.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(fetchModels.fulfilled, (state, action) => {
+      state.models = action.payload.models
+      if (action.payload.init) {
+        state.tableData = action.payload.models
+      }
+    })
+    builder.addCase(fetchModels.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(getModelDetails.fulfilled, (state, action) => {
+      state.activatedDetails = action.payload
+    })
+    builder.addCase(getModelDetails.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(registerModel.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(updateModel.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(deleteModel.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(fetchModelVersions.fulfilled, (state, action) => {
+      state.versions = action.payload.versions
+      if (action.payload.init) {
+        state.tableData = action.payload.versions
+      }
+    })
+    builder.addCase(fetchModelVersions.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(getVersionDetails.fulfilled, (state, action) => {
+      state.activatedDetails = action.payload
+    })
+    builder.addCase(getVersionDetails.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
+    builder.addCase(linkVersion.rejected, (state, action) => {
+      if (!action.error.message.includes('CanceledError')) {
+        toast.error(action.error.message)
+      }
+    })
   }
 })
 
